@@ -4,23 +4,23 @@ utils::periph! {
     /// Calibration Data
     CalibrationData;
     /// DCOCTL  Calibration Data for 12MHz
-    rw CALDCO_12MHZ @ 0x00: u8 = 0_0 {
+    rw DCO_12MHZ @ 0x00: u8 = 0_0 {
         /// DCOCTL  Calibration Data for 12MHz
-        CALDCO_12MHZ: 0..7 = struct CALDCO_12MHZField(u8);
+        DCO_12MHZ: 0..7 = struct DCO_12MHZField(u8);
     }
     /// BCSCTL1 Calibration Data for 12MHz
-    rw CALBC1_12MHZ @ 0x01: u8 = 0_0 {
+    rw BC1_12MHZ @ 0x01: u8 = 0_0 {
         /// BCSCTL1 Calibration Data for 12MHz
-        CALBC1_12MHZ: 0..7 = struct CALBC1_12MHZField(u8);
+        BC1_12MHZ: 0..7 = struct BC1_12MHZField(u8);
     }
     /// DCOCTL  Calibration Data for 8MHz
-    rw CALDCO_8MHZ @ 0x02: u8 = 0_0 {
+    rw DCO_8MHZ @ 0x02: u8 = 0_0 {
         /// DCOCTL  Calibration Data for 8MHz
-        CALDCO_8MHZ: 0..7 = struct CALDCO_8MHZField(u8);
+        DCO_8MHZ: 0..7 = struct DCO_8MHZField(u8);
     }
     /// BCSCTL1 Calibration Data for 8MHz
-    rw CALBC1_8MHZ @ 0x03: u8 = 0_0 {
+    rw BC1_8MHZ @ 0x03: u8 = 0_0 {
         /// BCSCTL1 Calibration Data for 8MHz
-        CALBC1_8MHZ: 0..7 = struct CALBC1_8MHZField(u8);
+        BC1_8MHZ: 0..7 = struct BC1_8MHZField(u8);
     }
 }
