@@ -4,13 +4,13 @@ utils::periph! {
     /// CRC16
     CRC16;
     /// CRC Data In Register
-    rw CRCDI @ 0x00: u16 = 0_0 {
+    rw DI @ 0x00: u16 = 0_0 {
         /// CRC Data In Register
-        CRCDI: 0..15 = struct CRCDIField(u16);
+        DI: 0..15 = struct DIField(u16);
     }
     /// CRC Initialisation Register and Result Register
-    rw CRCINIRES @ 0x04: u16 = 0_0 {
+    rw INIRES @ 0x04: u16 = 0_0 {
         /// CRC Initialisation Register and Result Register
-        CRCINIRES: 0..15 = struct CRCINIRESField(u16);
+        INIRES: 0..15 = struct INIRESField(u16);
     }
 }
