@@ -4,459 +4,459 @@ utils::periph! {
     /// eCOMP
     eCOMP;
     /// Comparator Control Register 0
-    rw CPCTL0 @ 0x00: u16 = 0_0 {
+    rw CTL0 @ 0x00: u16 = 0_0 {
         /// Channel input enable for the V+ terminal
-        CPPEN: 4 = enum CPPEN {
+        PEN: 4 = enum PEN {
             /// Selected analog input channel for V+ terminal is disabled.
-            CPPEN_0 = 0b0,
+            PEN_0 = 0b0,
             /// Selected analog input channel for V+ terminal is enabled.
-            CPPEN_1 = 0b1,
+            PEN_1 = 0b1,
         }
         /// Channel input selected for the - terminal
-        CPNSEL: 8..10 = enum CPNSEL {
+        NSEL: 8..10 = enum NSEL {
             /// select external input source
-            CPNSEL_0 = 0b000,
+            NSEL_0 = 0b000,
             /// select external input source
-            CPNSEL_1 = 0b001,
+            NSEL_1 = 0b001,
             /// select external input source
-            CPNSEL_2 = 0b010,
+            NSEL_2 = 0b010,
             /// select external input source
-            CPNSEL_3 = 0b011,
+            NSEL_3 = 0b011,
             /// device specific, please refer to device data sheet for details
-            CPNSEL_4 = 0b100,
+            NSEL_4 = 0b100,
             /// device specific, please refer to device data sheet for details
-            CPNSEL_5 = 0b101,
+            NSEL_5 = 0b101,
             /// 6-bit DAC
-            CPNSEL_6 = 0b110,
+            NSEL_6 = 0b110,
             /// Reserved
-            CPNSEL_7 = 0b111,
+            NSEL_7 = 0b111,
         }
         /// Channel input enable for the - terminal
-        CPNEN: 12 = enum CPNEN {
+        NEN: 12 = enum NEN {
             /// Selected analog input channel for V- terminal is disabled.
-            CPNEN_0 = 0b0,
+            NEN_0 = 0b0,
             /// Selected analog input channel for V- terminal is enabled.
-            CPNEN_1 = 0b1,
+            NEN_1 = 0b1,
         }
         /// Channel input selected for the V+ terminal
-        CPPSEL: 0..2 = enum CPPSEL {
+        PSEL: 0..2 = enum PSEL {
             /// select external input source
-            CPPSEL_0 = 0b000,
+            PSEL_0 = 0b000,
             /// select external input source
-            CPPSEL_1 = 0b001,
+            PSEL_1 = 0b001,
             /// select external input source
-            CPPSEL_2 = 0b010,
+            PSEL_2 = 0b010,
             /// select external input source
-            CPPSEL_3 = 0b011,
+            PSEL_3 = 0b011,
             /// device specific, please refer to device data sheet for details
-            CPPSEL_4 = 0b100,
+            PSEL_4 = 0b100,
             /// device specific, please refer to device data sheet for details
-            CPPSEL_5 = 0b101,
+            PSEL_5 = 0b101,
             /// 6-bit DAC
-            CPPSEL_6 = 0b110,
+            PSEL_6 = 0b110,
             /// Reserved
-            CPPSEL_7 = 0b111,
+            PSEL_7 = 0b111,
         }
     }
     /// Comparator Control Register 1
-    rw CPCTL1 @ 0x02: u16 = 0_0 {
+    rw CTL1 @ 0x02: u16 = 0_0 {
         /// Comparator output value
-        CPOUT: 0 = struct CPOUT(bool);
+        OUT: 0 = struct OUT(bool);
         /// Comparator output polarity
-        CPINV: 1 = enum CPINV {
+        INV: 1 = enum INV {
             /// Comparator output is non-inverted
-            CPINV_0 = 0b0,
+            INV_0 = 0b0,
             /// Comparator output is inverted
-            CPINV_1 = 0b1,
+            INV_1 = 0b1,
         }
         /// Interrupt edge select for CEIIFG and CEIFG
-        CPIES: 4 = enum CPIES {
+        IES: 4 = enum IES {
             /// Rising edge for CPIFG, falling edge for CPIIFG
-            CPIES_0 = 0b0,
+            IES_0 = 0b0,
             /// Falling edge for CPIFG, rising edge for CPIIFG
-            CPIES_1 = 0b1,
+            IES_1 = 0b1,
         }
         /// Analog Output Low Pass filter Selection. Changing CPFLT might set interrupt flag.
-        CPFLT: 5 = enum CPFLT {
+        FLT: 5 = enum FLT {
             /// Comparator output is not filtered
-            CPFLT_0 = 0b0,
+            FLT_0 = 0b0,
             /// Comparator output is filtered
-            CPFLT_1 = 0b1,
+            FLT_1 = 0b1,
         }
         /// Analog Filter Delay selection. These bits are used to select the analog filter delay
-        CPFLTDLY: 6..7 = enum CPFLTDLY {
+        FLTDLY: 6..7 = enum FLTDLY {
             /// Typical filter delay of 450ns
-            CPFLTDLY_0 = 0b00,
+            FLTDLY_0 = 0b00,
             /// Typical filter delay of 900ns
-            CPFLTDLY_1 = 0b01,
+            FLTDLY_1 = 0b01,
             /// Typical filter delay of 1800ns
-            CPFLTDLY_2 = 0b10,
+            FLTDLY_2 = 0b10,
             /// Typical filter delay of 3600ns
-            CPFLTDLY_3 = 0b11,
+            FLTDLY_3 = 0b11,
         }
         /// Power mode selection.
-        CPMSEL: 8 = enum CPMSEL {
+        MSEL: 8 = enum MSEL {
             /// High-power & High speed mode (500nA)
-            CPMSEL_0 = 0b0,
+            MSEL_0 = 0b0,
             /// Low-power & Low speed mode (10nA)
-            CPMSEL_1 = 0b1,
+            MSEL_1 = 0b1,
         }
         /// Comparator enable/disable. This bit is used to disable/enable the comparator. When the comparator is disabled, the Comparator consumes no power.
-        CPEN: 9 = enum CPEN {
+        EN: 9 = enum EN {
             /// Comparator is disabled
-            CPEN_0 = 0b0,
+            EN_0 = 0b0,
             /// Comparator is enabled
-            CPEN_1 = 0b1,
+            EN_1 = 0b1,
         }
         /// Programable Hysteresis mode. These bits are used to select the Hysteresis mode.
-        CPHSEL: 10..11 = enum CPHSEL {
+        HSEL: 10..11 = enum HSEL {
             /// disable
-            CPHSEL_0 = 0b00,
+            HSEL_0 = 0b00,
             /// 10mV
-            CPHSEL_1 = 0b01,
+            HSEL_1 = 0b01,
             /// 20mV
-            CPHSEL_2 = 0b10,
+            HSEL_2 = 0b10,
             /// 30mV
-            CPHSEL_3 = 0b11,
+            HSEL_3 = 0b11,
         }
         /// Comparator interrupt output enable bit
-        CPIE: 14 = enum CPIE {
+        IE: 14 = enum IE {
             /// Interrupt output is disabled
-            CPIE_0 = 0b0,
+            IE_0 = 0b0,
             /// Interrupt output is enabled
-            CPIE_1 = 0b1,
+            IE_1 = 0b1,
         }
         /// Comparator inverted interrupt output enable bit
-        CPIIE: 15 = enum CPIIE {
+        IIE: 15 = enum IIE {
             /// Interrupt inverted output is disabled
-            CPIIE_0 = 0b0,
+            IIE_0 = 0b0,
             /// Interrupt inverted output is enabled
-            CPIIE_1 = 0b1,
+            IIE_1 = 0b1,
         }
     }
     /// Comparator Interrupt Control Register
-    rw CPINT @ 0x06: u16 = 0_0 {
+    rw INT @ 0x06: u16 = 0_0 {
         /// Comparator output interrupt flag
-        CPIFG: 0 = enum CPIFG {
+        IFG: 0 = enum IFG {
             /// No interrupt pending.
-            CPIFG_0 = 0b0,
+            IFG_0 = 0b0,
             /// Output interrupt pending.
-            CPIFG_1 = 0b1,
+            IFG_1 = 0b1,
         }
         /// Comparator output inverted interrupt flag
-        CPIIFG: 1 = enum CPIIFG {
+        IIFG: 1 = enum IIFG {
             /// No interrupt pending.
-            CPIIFG_0 = 0b0,
+            IIFG_0 = 0b0,
             /// Output interrupt pending.
-            CPIIFG_1 = 0b1,
+            IIFG_1 = 0b1,
         }
     }
     /// Comparator Interrupt Vector Word Register
-    r CPIV @ 0x08: u16 = 0_0 {
+    r IV @ 0x08: u16 = 0_0 {
         /// Comparator interrupt vector word register
-        CPIV: 0..15 = enum CPIVField {
+        IV: 0..15 = enum IVField {
             /// No interrupt pending
             NONE = 0b0000000000000000,
             /// CPIFG
-            CPIFG = 0b0000000000000010,
+            IFG = 0b0000000000000010,
             /// CPIIFG
-            CPIIFG = 0b0000000000000100,
+            IIFG = 0b0000000000000100,
         }
     }
     /// 6-bit Comparator built-in DAC Control Register
-    rw CPDACCTL @ 0x10: u16 = 0_0 {
-        /// This bit is only valid when CPDACBUFS is set to 1.
-        CPDACSW: 0 = enum CPDACSW {
+    rw DACCTL @ 0x10: u16 = 0_0 {
+        /// This bit is only valid when DACBUFS is set to 1.
+        DACSW: 0 = enum DACSW {
             /// CPDACBUF1 selected
-            CPDACSW_0 = 0b0,
+            DACSW_0 = 0b0,
             /// CPDACBUF2 selected
-            CPDACSW_1 = 0b1,
+            DACSW_1 = 0b1,
         }
         /// Comparator built-in DAC buffer controlled source selection.
-        CPDACBUFS: 1 = enum CPDACBUFS {
+        DACBUFS: 1 = enum DACBUFS {
             /// Comparator output is selected as the buffer control source
-            CPDACBUFS_0 = 0b0,
+            DACBUFS_0 = 0b0,
             /// CPDACSW bit is selected as the buffer control source
-            CPDACBUFS_1 = 0b1,
+            DACBUFS_1 = 0b1,
         }
         /// Comparator built-in DAC reference voltage selection
-        CPDACREFS: 2 = enum CPDACREFS {
+        DACREFS: 2 = enum DACREFS {
             /// VDD selected
-            CPDACREFS_0 = 0b0,
+            DACREFS_0 = 0b0,
             /// on-chip VREF selected
-            CPDACREFS_1 = 0b1,
+            DACREFS_1 = 0b1,
         }
         /// Comparator built-in DAC output control bit.
-        CPDACEN: 7 = enum CPDACEN {
+        DACEN: 7 = enum DACEN {
             /// DAC output is disabled.
-            CPDACEN_0 = 0b0,
+            DACEN_0 = 0b0,
             /// DAC output is enabled.
-            CPDACEN_1 = 0b1,
+            DACEN_1 = 0b1,
         }
     }
     /// 6-bit Comparator built-in DAC Data Register
-    rw CPDACDATA @ 0x12: u16 = 0_0 {
+    rw DACDATA @ 0x12: u16 = 0_0 {
         /// 1st 6-bit DAC buffer Data
-        CPDACBUF1: 0..5 = enum CPDACBUF1 {
+        DACBUF1: 0..5 = enum DACBUF1 {
             /// 0v
-            CPDACBUF1_0 = 0b000000,
+            DACBUF1_0 = 0b000000,
             /// selected reference voltage * 1/64
-            CPDACBUF1_1 = 0b000001,
+            DACBUF1_1 = 0b000001,
             /// selected reference voltage * 2/64
-            CPDACBUF1_2 = 0b000010,
+            DACBUF1_2 = 0b000010,
             /// selected reference voltage * 3/64
-            CPDACBUF1_3 = 0b000011,
+            DACBUF1_3 = 0b000011,
             /// selected reference voltage * 4/64
-            CPDACBUF1_4 = 0b000100,
+            DACBUF1_4 = 0b000100,
             /// selected reference voltage * 5/64
-            CPDACBUF1_5 = 0b000101,
+            DACBUF1_5 = 0b000101,
             /// selected reference voltage * 6/64
-            CPDACBUF1_6 = 0b000110,
+            DACBUF1_6 = 0b000110,
             /// selected reference voltage * 7/64
-            CPDACBUF1_7 = 0b000111,
+            DACBUF1_7 = 0b000111,
             /// selected reference voltage * 8/64
-            CPDACBUF1_8 = 0b001000,
+            DACBUF1_8 = 0b001000,
             /// selected reference voltage *9/64
-            CPDACBUF1_9 = 0b001001,
+            DACBUF1_9 = 0b001001,
             /// selected reference voltage * 10/64
-            CPDACBUF1_10 = 0b001010,
+            DACBUF1_10 = 0b001010,
             /// selected reference voltage * 11/64
-            CPDACBUF1_11 = 0b001011,
+            DACBUF1_11 = 0b001011,
             /// selected reference voltage * 12/64
-            CPDACBUF1_12 = 0b001100,
+            DACBUF1_12 = 0b001100,
             /// selected reference voltage * 13/64
-            CPDACBUF1_13 = 0b001101,
+            DACBUF1_13 = 0b001101,
             /// selected reference voltage * 14/64
-            CPDACBUF1_14 = 0b001110,
+            DACBUF1_14 = 0b001110,
             /// selected reference voltage * 15/64
-            CPDACBUF1_15 = 0b001111,
+            DACBUF1_15 = 0b001111,
             /// selected reference voltage * 16/64
-            CPDACBUF1_16 = 0b010000,
+            DACBUF1_16 = 0b010000,
             /// selected reference voltage * 17/64
-            CPDACBUF1_17 = 0b010001,
+            DACBUF1_17 = 0b010001,
             /// selected reference voltage * 18/64
-            CPDACBUF1_18 = 0b010010,
+            DACBUF1_18 = 0b010010,
             /// selected reference voltage * 19/64
-            CPDACBUF1_19 = 0b010011,
+            DACBUF1_19 = 0b010011,
             /// selected reference voltage * 20/64
-            CPDACBUF1_20 = 0b010100,
+            DACBUF1_20 = 0b010100,
             /// selected reference voltage * 21/64
-            CPDACBUF1_21 = 0b010101,
+            DACBUF1_21 = 0b010101,
             /// selected reference voltage * 22/64
-            CPDACBUF1_22 = 0b010110,
+            DACBUF1_22 = 0b010110,
             /// selected reference voltage * 23/64
-            CPDACBUF1_23 = 0b010111,
+            DACBUF1_23 = 0b010111,
             /// selected reference voltage * 24/64
-            CPDACBUF1_24 = 0b011000,
+            DACBUF1_24 = 0b011000,
             /// selected reference voltage * 25/64
-            CPDACBUF1_25 = 0b011001,
+            DACBUF1_25 = 0b011001,
             /// selected reference voltage * 26/64
-            CPDACBUF1_26 = 0b011010,
+            DACBUF1_26 = 0b011010,
             /// selected reference voltage * 27/64
-            CPDACBUF1_27 = 0b011011,
+            DACBUF1_27 = 0b011011,
             /// selected reference voltage * 28/64
-            CPDACBUF1_28 = 0b011100,
+            DACBUF1_28 = 0b011100,
             /// selected reference voltage * 29/64
-            CPDACBUF1_29 = 0b011101,
+            DACBUF1_29 = 0b011101,
             /// selected reference voltage * 30/64
-            CPDACBUF1_30 = 0b011110,
+            DACBUF1_30 = 0b011110,
             /// selected reference voltage * 31/64
-            CPDACBUF1_31 = 0b011111,
+            DACBUF1_31 = 0b011111,
             /// selected reference voltage * 32/64
-            CPDACBUF1_32 = 0b100000,
+            DACBUF1_32 = 0b100000,
             /// selected reference voltage * 33/64
-            CPDACBUF1_33 = 0b100001,
+            DACBUF1_33 = 0b100001,
             /// selected reference voltage * 34/64
-            CPDACBUF1_34 = 0b100010,
+            DACBUF1_34 = 0b100010,
             /// selected reference voltage * 35/64
-            CPDACBUF1_35 = 0b100011,
+            DACBUF1_35 = 0b100011,
             /// selected reference voltage * 36/64
-            CPDACBUF1_36 = 0b100100,
+            DACBUF1_36 = 0b100100,
             /// selected reference voltage * 37/64
-            CPDACBUF1_37 = 0b100101,
+            DACBUF1_37 = 0b100101,
             /// selected reference voltage * 38/64
-            CPDACBUF1_38 = 0b100110,
+            DACBUF1_38 = 0b100110,
             /// selected reference voltage * 39/64
-            CPDACBUF1_39 = 0b100111,
+            DACBUF1_39 = 0b100111,
             /// selected reference voltage * 40/64
-            CPDACBUF1_40 = 0b101000,
+            DACBUF1_40 = 0b101000,
             /// selected reference voltage * 41/64
-            CPDACBUF1_41 = 0b101001,
+            DACBUF1_41 = 0b101001,
             /// selected reference voltage * 42/64
-            CPDACBUF1_42 = 0b101010,
+            DACBUF1_42 = 0b101010,
             /// selected reference voltage * 43/64
-            CPDACBUF1_43 = 0b101011,
+            DACBUF1_43 = 0b101011,
             /// selected reference voltage * 44/64
-            CPDACBUF1_44 = 0b101100,
+            DACBUF1_44 = 0b101100,
             /// selected reference voltage * 45/64
-            CPDACBUF1_45 = 0b101101,
+            DACBUF1_45 = 0b101101,
             /// selected reference voltage * 46/64
-            CPDACBUF1_46 = 0b101110,
+            DACBUF1_46 = 0b101110,
             /// selected reference voltage * 47/64
-            CPDACBUF1_47 = 0b101111,
+            DACBUF1_47 = 0b101111,
             /// selected reference voltage * 48/64
-            CPDACBUF1_48 = 0b110000,
+            DACBUF1_48 = 0b110000,
             /// selected reference voltage * 49/64
-            CPDACBUF1_49 = 0b110001,
+            DACBUF1_49 = 0b110001,
             /// selected reference voltage * 50/64
-            CPDACBUF1_50 = 0b110010,
+            DACBUF1_50 = 0b110010,
             /// selected reference voltage * 51/64
-            CPDACBUF1_51 = 0b110011,
+            DACBUF1_51 = 0b110011,
             /// selected reference voltage * 52/64
-            CPDACBUF1_52 = 0b110100,
+            DACBUF1_52 = 0b110100,
             /// selected reference voltage * 53/64
-            CPDACBUF1_53 = 0b110101,
+            DACBUF1_53 = 0b110101,
             /// selected reference voltage * 54/64
-            CPDACBUF1_54 = 0b110110,
+            DACBUF1_54 = 0b110110,
             /// selected reference voltage * 55/64
-            CPDACBUF1_55 = 0b110111,
+            DACBUF1_55 = 0b110111,
             /// selected reference voltage * 56/64
-            CPDACBUF1_56 = 0b111000,
+            DACBUF1_56 = 0b111000,
             /// selected reference voltage * 57/64
-            CPDACBUF1_57 = 0b111001,
+            DACBUF1_57 = 0b111001,
             /// selected reference voltage * 58/64
-            CPDACBUF1_58 = 0b111010,
+            DACBUF1_58 = 0b111010,
             /// selected reference voltage * 59/64
-            CPDACBUF1_59 = 0b111011,
+            DACBUF1_59 = 0b111011,
             /// selected reference voltage * 60/64
-            CPDACBUF1_60 = 0b111100,
+            DACBUF1_60 = 0b111100,
             /// selected reference voltage * 61/64
-            CPDACBUF1_61 = 0b111101,
+            DACBUF1_61 = 0b111101,
             /// selected reference voltage * 62/64
-            CPDACBUF1_62 = 0b111110,
+            DACBUF1_62 = 0b111110,
             /// selected reference voltage * 63/64
-            CPDACBUF1_63 = 0b111111,
+            DACBUF1_63 = 0b111111,
         }
         /// 2nd 6-bit DAC buffer Data
-        CPDACBUF2: 8..13 = enum CPDACBUF2 {
+        DACBUF2: 8..13 = enum DACBUF2 {
             /// 0v
-            CPDACBUF2_0 = 0b000000,
+            DACBUF2_0 = 0b000000,
             /// selected reference voltage * 1/64
-            CPDACBUF2_1 = 0b000001,
+            DACBUF2_1 = 0b000001,
             /// selected reference voltage * 2/64
-            CPDACBUF2_2 = 0b000010,
+            DACBUF2_2 = 0b000010,
             /// selected reference voltage * 3/64
-            CPDACBUF2_3 = 0b000011,
+            DACBUF2_3 = 0b000011,
             /// selected reference voltage * 4/64
-            CPDACBUF2_4 = 0b000100,
+            DACBUF2_4 = 0b000100,
             /// selected reference voltage * 5/64
-            CPDACBUF2_5 = 0b000101,
+            DACBUF2_5 = 0b000101,
             /// selected reference voltage * 6/64
-            CPDACBUF2_6 = 0b000110,
+            DACBUF2_6 = 0b000110,
             /// selected reference voltage * 7/64
-            CPDACBUF2_7 = 0b000111,
+            DACBUF2_7 = 0b000111,
             /// selected reference voltage * 8/64
-            CPDACBUF2_8 = 0b001000,
+            DACBUF2_8 = 0b001000,
             /// selected reference voltage * 9/64
-            CPDACBUF2_9 = 0b001001,
+            DACBUF2_9 = 0b001001,
             /// selected reference voltage * 10/64
-            CPDACBUF2_10 = 0b001010,
+            DACBUF2_10 = 0b001010,
             /// selected reference voltage * 11/64
-            CPDACBUF2_11 = 0b001011,
+            DACBUF2_11 = 0b001011,
             /// selected reference voltage * 12/64
-            CPDACBUF2_12 = 0b001100,
+            DACBUF2_12 = 0b001100,
             /// selected reference voltage * 13/64
-            CPDACBUF2_13 = 0b001101,
+            DACBUF2_13 = 0b001101,
             /// selected reference voltage * 14/64
-            CPDACBUF2_14 = 0b001110,
+            DACBUF2_14 = 0b001110,
             /// selected reference voltage * 15/64
-            CPDACBUF2_15 = 0b001111,
+            DACBUF2_15 = 0b001111,
             /// selected reference voltage * 16/64
-            CPDACBUF2_16 = 0b010000,
+            DACBUF2_16 = 0b010000,
             /// selected reference voltage * 17/64
-            CPDACBUF2_17 = 0b010001,
+            DACBUF2_17 = 0b010001,
             /// selected reference voltage * 18/64
-            CPDACBUF2_18 = 0b010010,
+            DACBUF2_18 = 0b010010,
             /// selected reference voltage * 19/64
-            CPDACBUF2_19 = 0b010011,
+            DACBUF2_19 = 0b010011,
             /// selected reference voltage * 20/64
-            CPDACBUF2_20 = 0b010100,
+            DACBUF2_20 = 0b010100,
             /// selected reference voltage * 21/64
-            CPDACBUF2_21 = 0b010101,
+            DACBUF2_21 = 0b010101,
             /// selected reference voltage * 22/64
-            CPDACBUF2_22 = 0b010110,
+            DACBUF2_22 = 0b010110,
             /// selected reference voltage * 23/64
-            CPDACBUF2_23 = 0b010111,
+            DACBUF2_23 = 0b010111,
             /// selected reference voltage * 24/64
-            CPDACBUF2_24 = 0b011000,
+            DACBUF2_24 = 0b011000,
             /// selected reference voltage * 25/64
-            CPDACBUF2_25 = 0b011001,
+            DACBUF2_25 = 0b011001,
             /// selected reference voltage * 26/64
-            CPDACBUF2_26 = 0b011010,
+            DACBUF2_26 = 0b011010,
             /// selected reference voltage * 27/64
-            CPDACBUF2_27 = 0b011011,
+            DACBUF2_27 = 0b011011,
             /// selected reference voltage * 28/64
-            CPDACBUF2_28 = 0b011100,
+            DACBUF2_28 = 0b011100,
             /// selected reference voltage * 29/64
-            CPDACBUF2_29 = 0b011101,
+            DACBUF2_29 = 0b011101,
             /// selected reference voltage * 30/64
-            CPDACBUF2_30 = 0b011110,
+            DACBUF2_30 = 0b011110,
             /// selected reference voltage * 31/64
-            CPDACBUF2_31 = 0b011111,
+            DACBUF2_31 = 0b011111,
             /// selected reference voltage * 32/64
-            CPDACBUF2_32 = 0b100000,
+            DACBUF2_32 = 0b100000,
             /// selected reference voltage * 33/64
-            CPDACBUF2_33 = 0b100001,
+            DACBUF2_33 = 0b100001,
             /// selected reference voltage * 34/64
-            CPDACBUF2_34 = 0b100010,
+            DACBUF2_34 = 0b100010,
             /// selected reference voltage * 35/64
-            CPDACBUF2_35 = 0b100011,
+            DACBUF2_35 = 0b100011,
             /// selected reference voltage * 36/64
-            CPDACBUF2_36 = 0b100100,
+            DACBUF2_36 = 0b100100,
             /// selected reference voltage * 37/64
-            CPDACBUF2_37 = 0b100101,
+            DACBUF2_37 = 0b100101,
             /// selected reference voltage * 38/64
-            CPDACBUF2_38 = 0b100110,
+            DACBUF2_38 = 0b100110,
             /// selected reference voltage * 39/64
-            CPDACBUF2_39 = 0b100111,
+            DACBUF2_39 = 0b100111,
             /// selected reference voltage * 40/64
-            CPDACBUF2_40 = 0b101000,
+            DACBUF2_40 = 0b101000,
             /// selected reference voltage * 41/64
-            CPDACBUF2_41 = 0b101001,
+            DACBUF2_41 = 0b101001,
             /// selected reference voltage * 42/64
-            CPDACBUF2_42 = 0b101010,
+            DACBUF2_42 = 0b101010,
             /// selected reference voltage * 43/64
-            CPDACBUF2_43 = 0b101011,
+            DACBUF2_43 = 0b101011,
             /// selected reference voltage * 44/64
-            CPDACBUF2_44 = 0b101100,
+            DACBUF2_44 = 0b101100,
             /// selected reference voltage * 45/64
-            CPDACBUF2_45 = 0b101101,
+            DACBUF2_45 = 0b101101,
             /// selected reference voltage * 46/64
-            CPDACBUF2_46 = 0b101110,
+            DACBUF2_46 = 0b101110,
             /// selected reference voltage * 47/64
-            CPDACBUF2_47 = 0b101111,
+            DACBUF2_47 = 0b101111,
             /// selected reference voltage * 48/64
-            CPDACBUF2_48 = 0b110000,
+            DACBUF2_48 = 0b110000,
             /// selected reference voltage * 49/64
-            CPDACBUF2_49 = 0b110001,
+            DACBUF2_49 = 0b110001,
             /// selected reference voltage * 50/64
-            CPDACBUF2_50 = 0b110010,
+            DACBUF2_50 = 0b110010,
             /// selected reference voltage * 51/64
-            CPDACBUF2_51 = 0b110011,
+            DACBUF2_51 = 0b110011,
             /// selected reference voltage * 52/64
-            CPDACBUF2_52 = 0b110100,
+            DACBUF2_52 = 0b110100,
             /// selected reference voltage * 53/64
-            CPDACBUF2_53 = 0b110101,
+            DACBUF2_53 = 0b110101,
             /// selected reference voltage * 54/64
-            CPDACBUF2_54 = 0b110110,
+            DACBUF2_54 = 0b110110,
             /// selected reference voltage * 55/64
-            CPDACBUF2_55 = 0b110111,
+            DACBUF2_55 = 0b110111,
             /// selected reference voltage * 56/64
-            CPDACBUF2_56 = 0b111000,
+            DACBUF2_56 = 0b111000,
             /// selected reference voltage * 57/64
-            CPDACBUF2_57 = 0b111001,
+            DACBUF2_57 = 0b111001,
             /// selected reference voltage * 58/64
-            CPDACBUF2_58 = 0b111010,
+            DACBUF2_58 = 0b111010,
             /// selected reference voltage * 59/64
-            CPDACBUF2_59 = 0b111011,
+            DACBUF2_59 = 0b111011,
             /// selected reference voltage * 60/64
-            CPDACBUF2_60 = 0b111100,
+            DACBUF2_60 = 0b111100,
             /// selected reference voltage * 61/64
-            CPDACBUF2_61 = 0b111101,
+            DACBUF2_61 = 0b111101,
             /// selected reference voltage * 62/64
-            CPDACBUF2_62 = 0b111110,
+            DACBUF2_62 = 0b111110,
             /// selected reference voltage * 63/64
-            CPDACBUF2_63 = 0b111111,
+            DACBUF2_63 = 0b111111,
         }
     }
 }
