@@ -4,51 +4,51 @@ utils::periph! {
     /// eUSCI_A
     eUSCI_A;
     /// eUSCI_Ax Control Word Register 0
-    rw UCACTLW0 @ 0x00: u16 = 0_0 {
+    rw CTLW0 @ 0x00: u16 = 0_0 {
         /// Software reset enable
-        UCACTLW0_UCSWRST: 0 = enum UCACTLW0_UCSWRST {
+        SWRST: 0 = enum SWRST {
             /// Disabled. eUSCI_A reset released for operation
             DISABLE = 0b0,
             /// Enabled. eUSCI_A logic held in reset state
             ENABLE = 0b1,
         }
         /// Transmit break
-        UCTXBRK: 1 = enum UCTXBRK {
+        TXBRK: 1 = enum TXBRK {
             /// Next frame transmitted is not a break
-            UCTXBRK_0 = 0b0,
+            TXBRK_0 = 0b0,
             /// Next frame transmitted is a break or a break/synch
-            UCTXBRK_1 = 0b1,
+            TXBRK_1 = 0b1,
         }
         /// Transmit address
-        UCTXADDR: 2 = enum UCTXADDR {
+        TXADDR: 2 = enum TXADDR {
             /// Next frame transmitted is data
-            UCTXADDR_0 = 0b0,
+            TXADDR_0 = 0b0,
             /// Next frame transmitted is an address
-            UCTXADDR_1 = 0b1,
+            TXADDR_1 = 0b1,
         }
         /// Dormant
-        UCDORM: 3 = enum UCDORM {
+        DORM: 3 = enum DORM {
             /// Not dormant. All received characters set UCRXIFG.
-            UCDORM_0 = 0b0,
+            DORM_0 = 0b0,
             /// Dormant. Only characters that are preceded by an idle-line or with address bit set UCRXIFG. In UART mode with automatic baud-rate detection, only the combination of a break and synch field sets UCRXIFG.
-            UCDORM_1 = 0b1,
+            DORM_1 = 0b1,
         }
         /// Receive break character interrupt enable
-        UCBRKIE: 4 = enum UCBRKIE {
+        BRKIE: 4 = enum BRKIE {
             /// Received break characters do not set UCRXIFG
-            UCBRKIE_0 = 0b0,
+            BRKIE_0 = 0b0,
             /// Received break characters set UCRXIFG
-            UCBRKIE_1 = 0b1,
+            BRKIE_1 = 0b1,
         }
         /// Receive erroneous-character interrupt enable
-        UCRXEIE: 5 = enum UCRXEIE {
+        RXEIE: 5 = enum RXEIE {
             /// Erroneous characters rejected and UCRXIFG is not set
-            UCRXEIE_0 = 0b0,
+            RXEIE_0 = 0b0,
             /// Erroneous characters received set UCRXIFG
-            UCRXEIE_1 = 0b1,
+            RXEIE_1 = 0b1,
         }
         /// eUSCI_A clock source select
-        UCACTLW0_UCSSEL: 6..7 = enum UCACTLW0_UCSSEL {
+        SSEL: 6..7 = enum SSEL {
             /// UCLK
             UCLK = 0b00,
             /// ACLK
@@ -56,476 +56,476 @@ utils::periph! {
             /// SMCLK
             SMCLK = 0b10,
             /// SMCLK
-            UCSSEL_3 = 0b11,
+            SSEL_3 = 0b11,
         }
         /// Synchronous mode enable
-        UCACTLW0_UCSYNC: 8 = enum UCACTLW0_UCSYNC {
+        SYNC: 8 = enum SYNC {
             /// Asynchronous mode
             ASYNC = 0b0,
             /// Synchronous mode
             SYNC = 0b1,
         }
         /// eUSCI_A mode
-        UCACTLW0_UCMODE: 9..10 = enum UCACTLW0_UCMODE {
+        MODE: 9..10 = enum MODE {
             /// UART mode
-            UCMODE_0 = 0b00,
+            MODE_0 = 0b00,
             /// Idle-line multiprocessor mode
-            UCMODE_1 = 0b01,
+            MODE_1 = 0b01,
             /// Address-bit multiprocessor mode
-            UCMODE_2 = 0b10,
+            MODE_2 = 0b10,
             /// UART mode with automatic baud-rate detection
-            UCMODE_3 = 0b11,
+            MODE_3 = 0b11,
         }
         /// Stop bit select
-        UCSPB: 11 = enum UCSPB {
+        SPB: 11 = enum SPB {
             /// One stop bit
-            UCSPB_0 = 0b0,
+            SPB_0 = 0b0,
             /// Two stop bits
-            UCSPB_1 = 0b1,
+            SPB_1 = 0b1,
         }
         /// Character length
-        UCACTLW0_UC7BIT: 12 = enum UCACTLW0_UC7BIT {
+        _7BIT: 12 = enum _7BIT {
             /// 8-bit data
             _8BIT = 0b0,
             /// 7-bit data
             _7BIT = 0b1,
         }
         /// MSB first select
-        UCACTLW0_UCMSB: 13 = enum UCACTLW0_UCMSB {
+        MSB: 13 = enum MSB {
             /// LSB first
-            UCMSB_0 = 0b0,
+            MSB_0 = 0b0,
             /// MSB first
-            UCMSB_1 = 0b1,
+            MSB_1 = 0b1,
         }
         /// Parity select
-        UCPAR: 14 = enum UCPAR {
+        PAR: 14 = enum PAR {
             /// Odd parity
             ODD = 0b0,
             /// Even parity
             EVEN = 0b1,
         }
         /// Parity enable
-        UCPEN: 15 = enum UCPEN {
+        PEN: 15 = enum PEN {
             /// Parity disabled
-            UCPEN_0 = 0b0,
+            PEN_0 = 0b0,
             /// Parity enabled. Parity bit is generated (UCAxTXD) and expected (UCAxRXD). In address-bit multiprocessor mode, the address bit is included in the parity calculation.
-            UCPEN_1 = 0b1,
+            PEN_1 = 0b1,
         }
     }
     /// eUSCI_Ax Control Word Register 0
-    rw UCACTLW0_SPI @ 0x00: u16 = 0_0 {
+    rw CTLW0_SPI @ 0x00: u16 = 0_0 {
         /// Software reset enable
-        UCACTLW0_SPI_UCSWRST: 0 = enum UCACTLW0_SPI_UCSWRST {
+        SWRST_SPI: 0 = enum SWRST_SPI {
             /// Disabled. eUSCI_A reset released for operation
             DISABLE = 0b0,
             /// Enabled. eUSCI_A logic held in reset state
             ENABLE = 0b1,
         }
         /// STE mode select in master mode.
-        UCSTEM: 1 = enum UCSTEM {
+        STEM: 1 = enum STEM {
             /// STE pin is used to prevent conflicts with other masters
-            UCSTEM_0 = 0b0,
+            STEM_0 = 0b0,
             /// STE pin is used to generate the enable signal for a 4-wire slave
-            UCSTEM_1 = 0b1,
+            STEM_1 = 0b1,
         }
         /// eUSCI_A clock source select
-        UCACTLW0_SPI_UCSSEL: 6..7 = enum UCACTLW0_SPI_UCSSEL {
+        SSEL_SPI: 6..7 = enum SSEL_SPI {
             /// Reserved
-            UCSSEL_0 = 0b00,
+            SSEL_0 = 0b00,
             /// ACLK
             ACLK = 0b01,
             /// SMCLK
             SMCLK = 0b10,
             /// SMCLK
-            UCSSEL_3 = 0b11,
+            SSEL_3 = 0b11,
         }
         /// Synchronous mode enable
-        UCACTLW0_SPI_UCSYNC: 8 = enum UCACTLW0_SPI_UCSYNC {
+        SYNC_SPI: 8 = enum SYNC_SPI {
             /// Asynchronous mode
             ASYNC = 0b0,
             /// Synchronous mode
             SYNC = 0b1,
         }
         /// eUSCI mode
-        UCACTLW0_SPI_UCMODE: 9..10 = enum UCACTLW0_SPI_UCMODE {
+        MODE_SPI: 9..10 = enum MODE_SPI {
             /// 3-pin SPI
-            UCMODE_0 = 0b00,
+            MODE_0 = 0b00,
             /// 4-pin SPI with UCxSTE active high: Slave enabled when UCxSTE = 1
-            UCMODE_1 = 0b01,
+            MODE_1 = 0b01,
             /// 4-pin SPI with UCxSTE active low: Slave enabled when UCxSTE = 0
-            UCMODE_2 = 0b10,
+            MODE_2 = 0b10,
             /// I2C mode
-            UCMODE_3 = 0b11,
+            MODE_3 = 0b11,
         }
         /// Master mode select
-        UCMST: 11 = enum UCMST {
+        MST: 11 = enum MST {
             /// Slave mode
             SLAVE = 0b0,
             /// Master mode
             MASTER = 0b1,
         }
         /// Character length
-        UCACTLW0_SPI_UC7BIT: 12 = enum UCACTLW0_SPI_UC7BIT {
+        _7BIT_SPI: 12 = enum _7BIT_SPI {
             /// 8-bit data
             _8BIT = 0b0,
             /// 7-bit data
             _7BIT = 0b1,
         }
         /// MSB first select
-        UCACTLW0_SPI_UCMSB: 13 = enum UCACTLW0_SPI_UCMSB {
+        MSB_SPI: 13 = enum MSB_SPI {
             /// LSB first
-            UCMSB_0 = 0b0,
+            MSB_0 = 0b0,
             /// MSB first
-            UCMSB_1 = 0b1,
+            MSB_1 = 0b1,
         }
         /// Clock polarity select
-        UCCKPL: 14 = enum UCCKPL {
+        CKPL: 14 = enum CKPL {
             /// The inactive state is low
             LOW = 0b0,
             /// The inactive state is high
             HIGH = 0b1,
         }
         /// Clock phase select
-        UCCKPH: 15 = enum UCCKPH {
+        CKPH: 15 = enum CKPH {
             /// Data is changed on the first UCLK edge and captured on the following edge.
-            UCCKPH_0 = 0b0,
+            CKPH_0 = 0b0,
             /// Data is captured on the first UCLK edge and changed on the following edge.
-            UCCKPH_1 = 0b1,
+            CKPH_1 = 0b1,
         }
     }
     /// eUSCI_Ax Control Word Register 1
-    rw UCACTLW1 @ 0x02: u16 = 0_0 {
+    rw CTLW1 @ 0x02: u16 = 0_0 {
         /// Deglitch time
-        UCGLIT: 0..1 = enum UCGLIT {
+        GLIT: 0..1 = enum GLIT {
             /// Approximately 2 ns (equivalent of 1 delay element)
-            UCGLIT_0 = 0b00,
+            GLIT_0 = 0b00,
             /// Approximately 50 ns
-            UCGLIT_1 = 0b01,
+            GLIT_1 = 0b01,
             /// Approximately 100 ns
-            UCGLIT_2 = 0b10,
+            GLIT_2 = 0b10,
             /// Approximately 200 ns
-            UCGLIT_3 = 0b11,
+            GLIT_3 = 0b11,
         }
     }
     /// eUSCI_Ax Baud Rate Control Word Register
-    rw UCABRW @ 0x06: u16 = 0_0 {
+    rw BRW @ 0x06: u16 = 0_0 {
         /// eUSCI_Ax Baud Rate Control Word Register
-        UCABRW: 0..15 = struct UCABRWField(u16);
+        BRW: 0..15 = struct BRWField(u16);
     }
     /// eUSCI_Ax Bit Rate Control Register 1
-    rw UCABRW_SPI @ 0x06: u16 = 0_0 {
+    rw BRW_SPI @ 0x06: u16 = 0_0 {
         /// eUSCI_Ax Bit Rate Control Register 1
-        UCABRW_SPI: 0..15 = struct UCABRW_SPIField(u16);
+        BRW_SPI: 0..15 = struct BRW_SPIField(u16);
     }
     /// eUSCI_Ax Modulation Control Word Register
-    rw UCAMCTLW @ 0x08: u16 = 0_0 {
+    rw MCTLW @ 0x08: u16 = 0_0 {
         /// Oversampling mode enabled
-        UCOS16: 0 = enum UCOS16 {
+        OS16: 0 = enum OS16 {
             /// Disabled
-            UCOS16_0 = 0b0,
+            OS16_0 = 0b0,
             /// Enabled
-            UCOS16_1 = 0b1,
+            OS16_1 = 0b1,
         }
         /// First modulation stage select
-        UCBRF: 4..7 = struct UCBRF(u16);
+        BRF: 4..7 = struct BRF(u16);
         /// Second modulation stage select
-        UCBRS: 8..15 = struct UCBRS(u16);
+        BRS: 8..15 = struct BRS(u16);
     }
     /// eUSCI_Ax Status Register
-    rw UCASTATW @ 0x0a: u16 = 0_0 {
+    rw STATW @ 0x0a: u16 = 0_0 {
         /// eUSCI_A busy
-        UCBUSY: 0 = enum UCBUSY {
+        BUSY: 0 = enum BUSY {
             /// eUSCI_A inactive
             IDLE = 0b0,
             /// eUSCI_A transmitting or receiving
             BUSY = 0b1,
         }
         /// Address received / Idle line detected
-        UCADDR_UCIDLE: 1 = enum UCADDR_UCIDLE {
+        ADDR_IDLE: 1 = enum ADDR_IDLE {
             /// UCADDR: Received character is data. UCIDLE: No idle line detected
-            UCADDR_UCIDLE_0 = 0b0,
+            ADDR_IDLE_0 = 0b0,
             /// UCADDR: Received character is an address. UCIDLE: Idle line detected
-            UCADDR_UCIDLE_1 = 0b1,
+            ADDR_IDLE_1 = 0b1,
         }
         /// Receive error flag
-        UCRXERR: 2 = enum UCRXERR {
+        RXERR: 2 = enum RXERR {
             /// No receive errors detected
-            UCRXERR_0 = 0b0,
+            RXERR_0 = 0b0,
             /// Receive error detected
-            UCRXERR_1 = 0b1,
+            RXERR_1 = 0b1,
         }
         /// Break detect flag
-        UCBRK: 3 = enum UCBRK {
+        BRK: 3 = enum BRK {
             /// No break condition
-            UCBRK_0 = 0b0,
+            BRK_0 = 0b0,
             /// Break condition occurred
-            UCBRK_1 = 0b1,
+            BRK_1 = 0b1,
         }
         /// Parity error flag. When UCPEN = 0, UCPE is read as 0. UCPE is cleared when UCAxRXBUF is read.
-        UCPE: 4 = enum UCPE {
+        PE: 4 = enum PE {
             /// No error
-            UCPE_0 = 0b0,
+            PE_0 = 0b0,
             /// Character received with parity error
-            UCPE_1 = 0b1,
+            PE_1 = 0b1,
         }
         /// Overrun error flag
-        UCASTATW_UCOE: 5 = enum UCASTATW_UCOE {
+        OE: 5 = enum OE {
             /// No error
-            UCOE_0 = 0b0,
+            OE_0 = 0b0,
             /// Overrun error occurred
-            UCOE_1 = 0b1,
+            OE_1 = 0b1,
         }
         /// Framing error flag
-        UCASTATW_UCFE: 6 = enum UCASTATW_UCFE {
+        FE: 6 = enum FE {
             /// No error
-            UCFE_0 = 0b0,
+            FE_0 = 0b0,
             /// Character received with low stop bit
-            UCFE_1 = 0b1,
+            FE_1 = 0b1,
         }
         /// Listen enable
-        UCASTATW_UCLISTEN: 7 = enum UCASTATW_UCLISTEN {
+        LISTEN: 7 = enum LISTEN {
             /// Disabled
-            UCLISTEN_0 = 0b0,
+            LISTEN_0 = 0b0,
             /// Enabled. UCAxTXD is internally fed back to the receiver
-            UCLISTEN_1 = 0b1,
+            LISTEN_1 = 0b1,
         }
     }
-    /// UCASTATW_SPI
-    rw UCASTATW_SPI @ 0x0a: u16 = 0_0 {
+    /// STATW_SPI
+    rw STATW_SPI @ 0x0a: u16 = 0_0 {
         /// Overrun error flag
-        UCASTATW_SPI_UCOE: 5 = enum UCASTATW_SPI_UCOE {
+        OE_SPI: 5 = enum OE_SPI {
             /// No error
-            UCOE_0 = 0b0,
+            OE_0 = 0b0,
             /// Overrun error occurred
-            UCOE_1 = 0b1,
+            OE_1 = 0b1,
         }
         /// Framing error flag
-        UCASTATW_SPI_UCFE: 6 = enum UCASTATW_SPI_UCFE {
+        FE_SPI: 6 = enum FE_SPI {
             /// No error
-            UCFE_0 = 0b0,
+            FE_0 = 0b0,
             /// Bus conflict occurred
-            UCFE_1 = 0b1,
+            FE_1 = 0b1,
         }
         /// Listen enable
-        UCASTATW_SPI_UCLISTEN: 7 = enum UCASTATW_SPI_UCLISTEN {
+        LISTEN_SPI: 7 = enum LISTEN_SPI {
             /// Disabled
-            UCLISTEN_0 = 0b0,
+            LISTEN_0 = 0b0,
             /// Enabled. UCAxTXD is internally fed back to the receiver
-            UCLISTEN_1 = 0b1,
+            LISTEN_1 = 0b1,
         }
     }
     /// eUSCI_Ax Receive Buffer Register
-    r UCARXBUF @ 0x0c: u16 = 0_0 {
+    r RXBUF @ 0x0c: u16 = 0_0 {
         /// Receive data buffer
-        UCARXBUF_UCRXBUF: 0..7 = struct UCARXBUF_UCRXBUF(u16);
+        RXBUF: 0..7 = struct RXBUFField(u16);
     }
     /// eUSCI_Ax Receive Buffer Register
-    r UCARXBUF_SPI @ 0x0c: u16 = 0_0 {
+    r RXBUF_SPI @ 0x0c: u16 = 0_0 {
         /// Receive data buffer
-        UCARXBUF_SPI_UCRXBUF: 0..7 = struct UCARXBUF_SPI_UCRXBUF(u16);
+        RXBUF_SPI: 0..7 = struct RXBUF_SPIField(u16);
     }
     /// eUSCI_Ax Transmit Buffer Register
-    rw UCATXBUF @ 0x0e: u16 = 0_0 {
+    rw TXBUF @ 0x0e: u16 = 0_0 {
         /// Transmit data buffer
-        UCATXBUF_UCTXBUF: 0..7 = struct UCATXBUF_UCTXBUF(u16);
+        TXBUF: 0..7 = struct TXBUFField(u16);
     }
     /// eUSCI_Ax Transmit Buffer Register
-    rw UCATXBUF_SPI @ 0x0e: u16 = 0_0 {
+    rw TXBUF_SPI @ 0x0e: u16 = 0_0 {
         /// Transmit data buffer
-        UCATXBUF_SPI_UCTXBUF: 0..7 = struct UCATXBUF_SPI_UCTXBUF(u16);
+        TXBUF_SPIField: 0..7 = struct TXBUF_SPIField(u16);
     }
     /// eUSCI_Ax Auto Baud Rate Control Register
-    rw UCAABCTL @ 0x10: u16 = 0_0 {
+    rw ABCTL @ 0x10: u16 = 0_0 {
         /// Automatic baud-rate detect enable
-        UCABDEN: 0 = enum UCABDEN {
+        ABDEN: 0 = enum ABDEN {
             /// Baud-rate detection disabled. Length of break and synch field is not measured.
-            UCABDEN_0 = 0b0,
+            ABDEN_0 = 0b0,
             /// Baud-rate detection enabled. Length of break and synch field is measured and baud-rate settings are changed accordingly.
-            UCABDEN_1 = 0b1,
+            ABDEN_1 = 0b1,
         }
         /// Break time out error
-        UCBTOE: 2 = enum UCBTOE {
+        BTOE: 2 = enum BTOE {
             /// No error
-            UCBTOE_0 = 0b0,
+            BTOE_0 = 0b0,
             /// Length of break field exceeded 22 bit times
-            UCBTOE_1 = 0b1,
+            BTOE_1 = 0b1,
         }
         /// Synch field time out error
-        UCSTOE: 3 = enum UCSTOE {
+        STOE: 3 = enum STOE {
             /// No error
-            UCSTOE_0 = 0b0,
+            STOE_0 = 0b0,
             /// Length of synch field exceeded measurable time
-            UCSTOE_1 = 0b1,
+            STOE_1 = 0b1,
         }
         /// Break/synch delimiter length
-        UCDELIM: 4..5 = enum UCDELIM {
+        DELIM: 4..5 = enum DELIM {
             /// 1 bit time
-            UCDELIM_0 = 0b00,
+            DELIM_0 = 0b00,
             /// 2 bit times
-            UCDELIM_1 = 0b01,
+            DELIM_1 = 0b01,
             /// 3 bit times
-            UCDELIM_2 = 0b10,
+            DELIM_2 = 0b10,
             /// 4 bit times
-            UCDELIM_3 = 0b11,
+            DELIM_3 = 0b11,
         }
     }
     /// eUSCI_Ax IrDA Control Word Register
-    rw UCAIRCTL @ 0x12: u16 = 0_0 {
+    rw IRCTL @ 0x12: u16 = 0_0 {
         /// IrDA encoder/decoder enable
-        UCIREN: 0 = enum UCIREN {
+        IREN: 0 = enum IREN {
             /// IrDA encoder/decoder disabled
-            UCIREN_0 = 0b0,
+            IREN_0 = 0b0,
             /// IrDA encoder/decoder enabled
-            UCIREN_1 = 0b1,
+            IREN_1 = 0b1,
         }
         /// IrDA transmit pulse clock select
-        UCIRTXCLK: 1 = enum UCIRTXCLK {
+        IRTXCLK: 1 = enum IRTXCLK {
             /// BRCLK
-            UCIRTXCLK_0 = 0b0,
+            IRTXCLK_0 = 0b0,
             /// BITCLK16 when UCOS16 = 1. Otherwise, BRCLK.
-            UCIRTXCLK_1 = 0b1,
+            IRTXCLK_1 = 0b1,
         }
         /// Transmit pulse length
-        UCIRTXPL: 2..7 = struct UCIRTXPL(u16);
+        IRTXPL: 2..7 = struct IRTXPL(u16);
         /// IrDA receive filter enabled
-        UCIRRXFE: 8 = enum UCIRRXFE {
+        IRRXFE: 8 = enum IRRXFE {
             /// Receive filter disabled
-            UCIRRXFE_0 = 0b0,
+            IRRXFE_0 = 0b0,
             /// Receive filter enabled
-            UCIRRXFE_1 = 0b1,
+            IRRXFE_1 = 0b1,
         }
         /// IrDA receive input UCAxRXD polarity
-        UCIRRXPL: 9 = enum UCIRRXPL {
+        IRRXPL: 9 = enum IRRXPL {
             /// IrDA transceiver delivers a high pulse when a light pulse is seen
             HIGH = 0b0,
             /// IrDA transceiver delivers a low pulse when a light pulse is seen
             LOW = 0b1,
         }
         /// Receive filter length
-        UCIRRXFL: 10..15 = struct UCIRRXFL(u16);
+        IRRXFL: 10..15 = struct IRRXFL(u16);
     }
     /// eUSCI_Ax Interrupt Enable Register
-    rw UCAIE @ 0x1a: u16 = 0_0 {
+    rw IE @ 0x1a: u16 = 0_0 {
         /// Receive interrupt enable
-        UCAIE_UCRXIE: 0 = enum UCAIE_UCRXIE {
+        RXIE: 0 = enum RXIE {
             /// Interrupt disabled
-            UCRXIE_0 = 0b0,
+            RXIE_0 = 0b0,
             /// Interrupt enabled
-            UCRXIE_1 = 0b1,
+            RXIE_1 = 0b1,
         }
         /// Transmit interrupt enable
-        UCAIE_UCTXIE: 1 = enum UCAIE_UCTXIE {
+        TXIE: 1 = enum TXIE {
             /// Interrupt disabled
-            UCTXIE_0 = 0b0,
+            TXIE_0 = 0b0,
             /// Interrupt enabled
-            UCTXIE_1 = 0b1,
+            TXIE_1 = 0b1,
         }
         /// Start bit interrupt enable
-        UCSTTIE: 2 = enum UCSTTIE {
+        STTIE: 2 = enum STTIE {
             /// Interrupt disabled
-            UCSTTIE_0 = 0b0,
+            STTIE_0 = 0b0,
             /// Interrupt enabled
-            UCSTTIE_1 = 0b1,
+            STTIE_1 = 0b1,
         }
         /// Transmit complete interrupt enable
-        UCTXCPTIE: 3 = enum UCTXCPTIE {
+        TXCPTIE: 3 = enum TXCPTIE {
             /// Interrupt disabled
-            UCTXCPTIE_0 = 0b0,
+            TXCPTIE_0 = 0b0,
             /// Interrupt enabled
-            UCTXCPTIE_1 = 0b1,
+            TXCPTIE_1 = 0b1,
         }
     }
     /// eUSCI_Ax Interrupt Enable Register
-    rw UCAIE_SPI @ 0x1a: u16 = 0_0 {
+    rw IE_SPI @ 0x1a: u16 = 0_0 {
         /// Receive interrupt enable
-        UCAIE_SPI_UCRXIE: 0 = enum UCAIE_SPI_UCRXIE {
+        RXIE_SPI: 0 = enum RXIE_SPI {
             /// Interrupt disabled
-            UCRXIE_0 = 0b0,
+            RXIE_0 = 0b0,
             /// Interrupt enabled
-            UCRXIE_1 = 0b1,
+            RXIE_1 = 0b1,
         }
         /// Transmit interrupt enable
-        UCAIE_SPI_UCTXIE: 1 = enum UCAIE_SPI_UCTXIE {
+        TXIE_SPI: 1 = enum TXIE_SPI {
             /// Interrupt disabled
-            UCTXIE_0 = 0b0,
+            TXIE_0 = 0b0,
             /// Interrupt enabled
-            UCTXIE_1 = 0b1,
+            TXIE_1 = 0b1,
         }
     }
     /// eUSCI_Ax Interrupt Flag Register
-    rw UCAIFG @ 0x1c: u16 = 0_0 {
+    rw IFG @ 0x1c: u16 = 0_0 {
         /// Receive interrupt flag
-        UCAIFG_UCRXIFG: 0 = enum UCAIFG_UCRXIFG {
+        RXIFG: 0 = enum RXIFG {
             /// No interrupt pending
-            UCRXIFG_0 = 0b0,
+            RXIFG_0 = 0b0,
             /// Interrupt pending
-            UCRXIFG_1 = 0b1,
+            RXIFG_1 = 0b1,
         }
         /// Transmit interrupt flag
-        UCAIFG_UCTXIFG: 1 = enum UCAIFG_UCTXIFG {
+        TXIFG: 1 = enum TXIFG {
             /// No interrupt pending
-            UCTXIFG_0 = 0b0,
+            TXIFG_0 = 0b0,
             /// Interrupt pending
-            UCTXIFG_1 = 0b1,
+            TXIFG_1 = 0b1,
         }
         /// Start bit interrupt flag
-        UCSTTIFG: 2 = enum UCSTTIFG {
+        STTIFG: 2 = enum STTIFG {
             /// No interrupt pending
-            UCSTTIFG_0 = 0b0,
+            STTIFG_0 = 0b0,
             /// Interrupt pending
-            UCSTTIFG_1 = 0b1,
+            STTIFG_1 = 0b1,
         }
         /// Transmit ready interrupt enable
-        UCTXCPTIFG: 3 = enum UCTXCPTIFG {
+        TXCPTIFG: 3 = enum TXCPTIFG {
             /// No interrupt pending
-            UCTXCPTIFG_0 = 0b0,
+            TXCPTIFG_0 = 0b0,
             /// Interrupt pending
-            UCTXCPTIFG_1 = 0b1,
+            TXCPTIFG_1 = 0b1,
         }
     }
     /// eUSCI_Ax Interrupt Flag Register
-    rw UCAIFG_SPI @ 0x1c: u16 = 0_0 {
+    rw IFG_SPI @ 0x1c: u16 = 0_0 {
         /// Receive interrupt flag
-        UCAIFG_SPI_UCRXIFG: 0 = enum UCAIFG_SPI_UCRXIFG {
+        RXIFG_SPI: 0 = enum RXIFG_SPI {
             /// No interrupt pending
-            UCRXIFG_0 = 0b0,
+            RXIFG_0 = 0b0,
             /// Interrupt pending
-            UCRXIFG_1 = 0b1,
+            RXIFG_1 = 0b1,
         }
         /// Transmit interrupt flag
-        UCAIFG_SPI_UCTXIFG: 1 = enum UCAIFG_SPI_UCTXIFG {
+        TXIFG_SPI: 1 = enum TXIFG_SPI {
             /// No interrupt pending
-            UCTXIFG_0 = 0b0,
+            TXIFG_0 = 0b0,
             /// Interrupt pending
-            UCTXIFG_1 = 0b1,
+            TXIFG_1 = 0b1,
         }
     }
     /// eUSCI_Ax Interrupt Vector Register
-    r UCAIV @ 0x1e: u16 = 0_0 {
+    r IV @ 0x1e: u16 = 0_0 {
         /// eUSCI_A interrupt vector value
-        UCAIV_UCIV: 0..15 = enum UCAIV_UCIV {
+        IV: 0..15 = enum IVField {
             /// No interrupt pending
             NONE = 0b0000000000000000,
             /// Interrupt Source: Receive buffer full; Interrupt Flag: UCRXIFG; Interrupt Priority: Highest
-            UCRXIFG = 0b0000000000000010,
+            RXIFG = 0b0000000000000010,
             /// Interrupt Source: Transmit buffer empty; Interrupt Flag: UCTXIFG
-            UCTXIFG = 0b0000000000000100,
+            TXIFG = 0b0000000000000100,
             /// Interrupt Source: Start bit received; Interrupt Flag: UCSTTIFG
-            UCSTTIFG = 0b0000000000000110,
+            STTIFG = 0b0000000000000110,
             /// Interrupt Source: Transmit complete; Interrupt Flag: UCTXCPTIFG; Interrupt Priority: Lowest
-            UCTXCPTIFG = 0b0000000000001000,
+            TXCPTIFG = 0b0000000000001000,
         }
     }
     /// eUSCI_Ax Interrupt Vector Register
-    r UCAIV_SPI @ 0x1e: u16 = 0_0 {
+    r IV_SPI @ 0x1e: u16 = 0_0 {
         /// eUSCI_A interrupt vector value
-        UCAIV_SPI_UCIV: 0..15 = enum UCAIV_SPI_UCIV {
+        IV_SPI: 0..15 = enum IV_SPIField {
             /// No interrupt pending
             NONE = 0b0000000000000000,
             /// Interrupt Source: Data received; Interrupt Flag: UCRXIFG; Interrupt Priority: Highest
-            UCRXIFG = 0b0000000000000010,
+            RXIFG = 0b0000000000000010,
             /// Interrupt Source: Transmit buffer empty; Interrupt Flag: UCTXIFG; Interrupt Priority: Lowest
-            UCTXIFG = 0b0000000000000100,
+            TXIFG = 0b0000000000000100,
         }
     }
 }
