@@ -4,118 +4,118 @@ utils::periph! {
     /// RTC_CE  Real Time Clock
     RTC_CE;
     /// Real Timer Clock Control 0/Key
-    rw RTCCTL0 @ 0x00: u16 = 0_0 {
+    rw CTL0 @ 0x00: u16 = 0_0 {
         /// RTC Ready Interrupt Flag
-        RTCRDYIFG: 0 = struct RTCRDYIFG(bool);
+        RDYIFG: 0 = struct RDYIFG(bool);
         /// RTC Alarm Interrupt Flag
-        RTCAIFG: 1 = struct RTCAIFG(bool);
+        AIFG: 1 = struct AIFG(bool);
         /// RTC Time Event Interrupt Flag
-        RTCTEVIFG: 2 = struct RTCTEVIFG(bool);
+        TEVIFG: 2 = struct TEVIFG(bool);
         /// RTC 32kHz cyrstal oscillator fault interrupt flag
-        RTCOFIFG: 3 = struct RTCOFIFG(bool);
+        OFIFG: 3 = struct OFIFG(bool);
         /// RTC Ready Interrupt Enable Flag
-        RTCRDYIE: 4 = struct RTCRDYIE(bool);
+        RDYIE: 4 = struct RDYIE(bool);
         /// RTC Alarm Interrupt Enable Flag
-        RTCAIE: 5 = struct RTCAIE(bool);
+        AIE: 5 = struct AIE(bool);
         /// RTC Time Event Interrupt Enable Flag
-        RTCTEVIE: 6 = struct RTCTEVIE(bool);
+        TEVIE: 6 = struct TEVIE(bool);
         /// RTC 32kHz cyrstal oscillator fault interrupt enable
-        RTCOFIE: 7 = struct RTCOFIE(bool);
+        OFIE: 7 = struct OFIE(bool);
     }
     /// Real Timer Clock Control 1/3
-    rw RTCCTL13 @ 0x02: u16 = 0_0 {
+    rw CTL13 @ 0x02: u16 = 0_0 {
         /// RTC Time Event 1
-        RTCTEV: 0..1 = enum RTCTEV {
+        TEV: 0..1 = enum TEV {
             /// RTC Time Event: 0 (Min. changed)
-            RTCTEV_0 = 0b00,
+            TEV_0 = 0b00,
             /// RTC Time Event: 1 (Hour changed)
-            RTCTEV_1 = 0b01,
+            TEV_1 = 0b01,
             /// RTC Time Event: 2 (12:00 changed)
-            RTCTEV_2 = 0b10,
+            TEV_2 = 0b10,
             /// RTC Time Event: 3 (00:00 changed)
-            RTCTEV_3 = 0b11,
+            TEV_3 = 0b11,
         }
         /// RTC Source Select 1
-        RTCSSEL: 2..3 = enum RTCSSEL {
+        SSEL: 2..3 = enum SSEL {
             /// RTC Source Select ACLK
-            RTCSSEL_0 = 0b00,
+            SSEL_0 = 0b00,
             /// RTC Source Select SMCLK
-            RTCSSEL_1 = 0b01,
+            SSEL_1 = 0b01,
             /// RTC Source Select RT1PS
-            RTCSSEL_2 = 0b10,
+            SSEL_2 = 0b10,
             /// RTC Source Select RT1PS
-            RTCSSEL_3 = 0b11,
+            SSEL_3 = 0b11,
         }
         /// RTC Ready
-        RTCRDY: 4 = struct RTCRDY(bool);
+        RDY: 4 = struct RDY(bool);
         /// RTC Mode 0:Counter / 1: Calendar
-        RTCMODE: 5 = struct RTCMODE(bool);
+        MODE: 5 = struct MODE(bool);
         /// RTC Hold
-        RTCHOLD: 6 = struct RTCHOLD(bool);
+        HOLD: 6 = struct HOLD(bool);
         /// RTC BCD  0:Binary / 1:BCD
-        RTCBCD: 7 = struct RTCBCD(bool);
+        BCD: 7 = struct BCD(bool);
         /// RTC Calibration Frequency Bit 1
-        RTCCALF: 8..9 = enum RTCCALF {
+        CALF: 8..9 = enum CALF {
             /// RTC Calibration Frequency: No Output
-            RTCCALF_0 = 0b00,
+            CALF_0 = 0b00,
             /// RTC Calibration Frequency: 512 Hz
-            RTCCALF_1 = 0b01,
+            CALF_1 = 0b01,
             /// RTC Calibration Frequency: 256 Hz
-            RTCCALF_2 = 0b10,
+            CALF_2 = 0b10,
             /// RTC Calibration Frequency: 1 Hz
-            RTCCALF_3 = 0b11,
+            CALF_3 = 0b11,
         }
         /// RTC Real-Time clock lock
-        RTCLOCK: 10 = struct RTCLOCK(bool);
+        LOCK: 10 = struct LOCK(bool);
     }
     /// Real Timer Clock Offset Calibartion
-    rw RTCOCAL @ 0x04: u16 = 0_0 {
+    rw OCAL @ 0x04: u16 = 0_0 {
         /// RTC Offset Calibration Bit 0
-        RTCOCAL0: 0 = struct RTCOCAL0(bool);
+        OCAL0: 0 = struct OCAL0(bool);
         /// RTC Offset Calibration Bit 1
-        RTCOCAL1: 1 = struct RTCOCAL1(bool);
+        OCAL1: 1 = struct OCAL1(bool);
         /// RTC Offset Calibration Bit 2
-        RTCOCAL2: 2 = struct RTCOCAL2(bool);
+        OCAL2: 2 = struct OCAL2(bool);
         /// RTC Offset Calibration Bit 3
-        RTCOCAL3: 3 = struct RTCOCAL3(bool);
+        OCAL3: 3 = struct OCAL3(bool);
         /// RTC Offset Calibration Bit 4
-        RTCOCAL4: 4 = struct RTCOCAL4(bool);
+        OCAL4: 4 = struct OCAL4(bool);
         /// RTC Offset Calibration Bit 5
-        RTCOCAL5: 5 = struct RTCOCAL5(bool);
+        OCAL5: 5 = struct OCAL5(bool);
         /// RTC Offset Calibration Bit 6
-        RTCOCAL6: 6 = struct RTCOCAL6(bool);
+        OCAL6: 6 = struct OCAL6(bool);
         /// RTC Offset Calibration Bit 7
-        RTCOCAL7: 7 = struct RTCOCAL7(bool);
+        OCAL7: 7 = struct OCAL7(bool);
         /// RTC Offset Calibration Sign
-        RTCOCALS: 15 = struct RTCOCALS(bool);
+        OCALS: 15 = struct OCALS(bool);
     }
     /// Real Timer Temperature Compensation
-    rw RTCTCMP @ 0x06: u16 = 0_0 {
+    rw TCMP @ 0x06: u16 = 0_0 {
         /// RTC Temperature Compensation Bit 0
-        RTCTCMP0: 0 = struct RTCTCMP0(bool);
+        TCMP0: 0 = struct TCMP0(bool);
         /// RTC Temperature Compensation Bit 1
-        RTCTCMP1: 1 = struct RTCTCMP1(bool);
+        TCMP1: 1 = struct TCMP1(bool);
         /// RTC Temperature Compensation Bit 2
-        RTCTCMP2: 2 = struct RTCTCMP2(bool);
+        TCMP2: 2 = struct TCMP2(bool);
         /// RTC Temperature Compensation Bit 3
-        RTCTCMP3: 3 = struct RTCTCMP3(bool);
+        TCMP3: 3 = struct TCMP3(bool);
         /// RTC Temperature Compensation Bit 4
-        RTCTCMP4: 4 = struct RTCTCMP4(bool);
+        TCMP4: 4 = struct TCMP4(bool);
         /// RTC Temperature Compensation Bit 5
-        RTCTCMP5: 5 = struct RTCTCMP5(bool);
+        TCMP5: 5 = struct TCMP5(bool);
         /// RTC Temperature Compensation Bit 6
-        RTCTCMP6: 6 = struct RTCTCMP6(bool);
+        TCMP6: 6 = struct TCMP6(bool);
         /// RTC Temperature Compensation Bit 7
-        RTCTCMP7: 7 = struct RTCTCMP7(bool);
+        TCMP7: 7 = struct TCMP7(bool);
         /// RTC Temperature compensation write OK
-        RTCTCOK: 13 = struct RTCTCOK(bool);
+        TCOK: 13 = struct TCOK(bool);
         /// RTC Temperature compensation ready
-        RTCTCRDY: 14 = struct RTCTCRDY(bool);
+        TCRDY: 14 = struct TCRDY(bool);
         /// RTC Temperature Compensation Sign
-        RTCTCMPS: 15 = struct RTCTCMPS(bool);
+        TCMPS: 15 = struct TCMPS(bool);
     }
     /// Real Timer Prescale Timer 0 Control
-    rw RTCPS0CTL @ 0x08: u16 = 0_0 {
+    rw PS0CTL @ 0x08: u16 = 0_0 {
         /// RTC Prescale Timer 0 Interrupt Flag
         RT0PSIFG: 0 = struct RT0PSIFG(bool);
         /// RTC Prescale Timer 0 Interrupt Enable Flag
@@ -220,44 +220,44 @@ utils::periph! {
         }
     }
     /// Real Timer Prescale Timer Control
-    rw RTCPS @ 0x0c: u16 = 0_0 {
+    rw PS @ 0x0c: u16 = 0_0 {
         /// Real Timer Prescale Timer Control
-        RTCPS: 0..15 = struct RTCPSField(u16);
+        PS: 0..15 = struct PSField(u16);
     }
     /// Real Time Clock Interrupt Vector
-    rw RTCIV @ 0x0e: u16 = 0_0 {
+    rw IV @ 0x0e: u16 = 0_0 {
         /// Real Time Clock Interrupt Vector
-        RTCIV: 0..15 = struct RTCIVField(u16);
+        IV: 0..15 = struct IVField(u16);
     }
     /// Real Time Clock Time 0
-    rw RTCTIM0 @ 0x10: u16 = 0_0 {
+    rw TIM0 @ 0x10: u16 = 0_0 {
         /// Real Time Clock Time 0
-        RTCTIM0: 0..15 = struct RTCTIM0Field(u16);
+        TIM0: 0..15 = struct TIM0Field(u16);
     }
     /// Real Time Clock Time 1
-    rw RTCTIM1 @ 0x12: u16 = 0_0 {
+    rw TIM1 @ 0x12: u16 = 0_0 {
         /// Real Time Clock Time 1
-        RTCTIM1: 0..15 = struct RTCTIM1Field(u16);
+        TIM1: 0..15 = struct TIM1Field(u16);
     }
     /// Real Time Clock Date
-    rw RTCDATE @ 0x14: u16 = 0_0 {
+    rw DATE @ 0x14: u16 = 0_0 {
         /// Real Time Clock Date
-        RTCDATE: 0..15 = struct RTCDATEField(u16);
+        DATE: 0..15 = struct DATEField(u16);
     }
     /// Real Time Clock Year
-    rw RTCYEAR @ 0x16: u16 = 0_0 {
+    rw YEAR @ 0x16: u16 = 0_0 {
         /// Real Time Clock Year
-        RTCYEAR: 0..15 = struct RTCYEARField(u16);
+        YEAR: 0..15 = struct YEARField(u16);
     }
     /// Real Time Clock Alarm Min/Hour
-    rw RTCAMINHR @ 0x18: u16 = 0_0 {
+    rw AMINHR @ 0x18: u16 = 0_0 {
         /// Real Time Clock Alarm Min/Hour
-        RTCAMINHR: 0..15 = struct RTCAMINHRField(u16);
+        AMINHR: 0..15 = struct AMINHRField(u16);
     }
     /// Real Time Clock Alarm day of week/day
-    rw RTCADOWDAY @ 0x1a: u16 = 0_0 {
+    rw ADOWDAY @ 0x1a: u16 = 0_0 {
         /// Real Time Clock Alarm day of week/day
-        RTCADOWDAY: 0..15 = struct RTCADOWDAYField(u16);
+        ADOWDAY: 0..15 = struct ADOWDAYField(u16);
     }
     /// Real Time Binary-to-BCD conversion register
     rw BIN2BCD @ 0x1c: u16 = 0_0 {
@@ -270,7 +270,7 @@ utils::periph! {
         BCD2BIN: 0..15 = struct BCD2BINField(u16);
     }
     /// Real Time Clock Seconds
-    rw RTCSEC @ 0x10: u8 = 0_0 {
+    rw SEC @ 0x10: u8 = 0_0 {
         /// Real Time Clock Seconds Bit: 0
         SECONDS0: 0 = struct SECONDS0(bool);
         /// Real Time Clock Seconds Bit: 1
@@ -287,75 +287,75 @@ utils::periph! {
         SECONDS6: 6 = struct SECONDS6(bool);
     }
     /// Real Time Clock Minutes
-    rw RTCMIN @ 0x11: u8 = 0_0 {
+    rw MIN @ 0x11: u8 = 0_0 {
         /// Real Time Clock Minutes Bit: 0
-        RTCMIN_MINUTES0: 0 = struct RTCMIN_MINUTES0(bool);
+        MIN0: 0 = struct MIN0(bool);
         /// Real Time Clock Minutes Bit: 1
-        RTCMIN_MINUTES1: 1 = struct RTCMIN_MINUTES1(bool);
+        MIN1: 1 = struct MIN1(bool);
         /// Real Time Clock Minutes Bit: 2
-        RTCMIN_MINUTES2: 2 = struct RTCMIN_MINUTES2(bool);
+        MIN2: 2 = struct MIN2(bool);
         /// Real Time Clock Minutes Bit: 3
-        RTCMIN_MINUTES3: 3 = struct RTCMIN_MINUTES3(bool);
+        MIN3: 3 = struct MIN3(bool);
         /// Real Time Clock Minutes Bit: 4
-        RTCMIN_MINUTES4: 4 = struct RTCMIN_MINUTES4(bool);
+        MIN4: 4 = struct MIN4(bool);
         /// Real Time Clock Minutes Bit: 5
-        RTCMIN_MINUTES5: 5 = struct RTCMIN_MINUTES5(bool);
+        MIN5: 5 = struct MIN5(bool);
         /// Real Time Clock Minutes Bit: 6
-        RTCMIN_MINUTES6: 6 = struct RTCMIN_MINUTES6(bool);
+        MIN6: 6 = struct MIN6(bool);
     }
     /// Real Time Clock Hour
-    rw RTCHOUR @ 0x12: u8 = 0_0 {
+    rw HOUR @ 0x12: u8 = 0_0 {
         /// Real Time Clock Hour Bit: 0
-        RTCHOUR_HOUR0: 0 = struct RTCHOUR_HOUR0(bool);
+        HOUR0: 0 = struct HOUR0(bool);
         /// Real Time Clock Hour Bit: 1
-        RTCHOUR_HOUR1: 1 = struct RTCHOUR_HOUR1(bool);
+        HOUR1: 1 = struct HOUR1(bool);
         /// Real Time Clock Hour Bit: 2
-        RTCHOUR_HOUR2: 2 = struct RTCHOUR_HOUR2(bool);
+        HOUR2: 2 = struct HOUR2(bool);
         /// Real Time Clock Hour Bit: 3
-        RTCHOUR_HOUR3: 3 = struct RTCHOUR_HOUR3(bool);
+        HOUR3: 3 = struct HOUR3(bool);
         /// Real Time Clock Hour Bit: 4
-        RTCHOUR_HOUR4: 4 = struct RTCHOUR_HOUR4(bool);
+        HOUR4: 4 = struct HOUR4(bool);
         /// Real Time Clock Hour Bit: 5
-        RTCHOUR_HOUR5: 5 = struct RTCHOUR_HOUR5(bool);
+        HOUR5: 5 = struct HOUR5(bool);
         /// Real Time Clock Hour Bit: 6
-        RTCHOUR_HOUR6: 6 = struct RTCHOUR_HOUR6(bool);
+        HOUR6: 6 = struct HOUR6(bool);
     }
     /// Real Time Clock Day of week
-    rw RTCDOW @ 0x13: u8 = 0_0 {
+    rw DOW @ 0x13: u8 = 0_0 {
         /// Real Time Clock DOW Bit: 0
-        RTCDOW_DOW0: 0 = struct RTCDOW_DOW0(bool);
+        DOW0: 0 = struct DOW0(bool);
         /// Real Time Clock DOW Bit: 1
-        RTCDOW_DOW1: 1 = struct RTCDOW_DOW1(bool);
+        DOW1: 1 = struct DOW1(bool);
         /// Real Time Clock DOW Bit: 2
-        RTCDOW_DOW2: 2 = struct RTCDOW_DOW2(bool);
+        DOW2: 2 = struct DOW2(bool);
         /// Real Time Clock DOW Bit: 3
-        RTCDOW_DOW3: 3 = struct RTCDOW_DOW3(bool);
+        DOW3: 3 = struct DOW3(bool);
         /// Real Time Clock DOW Bit: 4
-        RTCDOW_DOW4: 4 = struct RTCDOW_DOW4(bool);
+        DOW4: 4 = struct DOW4(bool);
         /// Real Time Clock DOW Bit: 5
-        RTCDOW_DOW5: 5 = struct RTCDOW_DOW5(bool);
+        DOW5: 5 = struct DOW5(bool);
         /// Real Time Clock DOW Bit: 6
-        RTCDOW_DOW6: 6 = struct RTCDOW_DOW6(bool);
+        DOW6: 6 = struct DOW6(bool);
     }
     /// Real Time Clock Day
-    rw RTCDAY @ 0x14: u8 = 0_0 {
+    rw DAY @ 0x14: u8 = 0_0 {
         /// Real Time Clock Day Bit: 0
-        RTCDAY_DAY0: 0 = struct RTCDAY_DAY0(bool);
+        DAY0: 0 = struct DAY0(bool);
         /// Real Time Clock Day Bit: 1
-        RTCDAY_DAY1: 1 = struct RTCDAY_DAY1(bool);
+        DAY1: 1 = struct DAY1(bool);
         /// Real Time Clock Day Bit: 2
-        RTCDAY_DAY2: 2 = struct RTCDAY_DAY2(bool);
+        DAY2: 2 = struct DAY2(bool);
         /// Real Time Clock Day Bit: 3
-        RTCDAY_DAY3: 3 = struct RTCDAY_DAY3(bool);
+        DAY3: 3 = struct DAY3(bool);
         /// Real Time Clock Day Bit: 4
-        RTCDAY_DAY4: 4 = struct RTCDAY_DAY4(bool);
+        DAY4: 4 = struct DAY4(bool);
         /// Real Time Clock Day Bit: 5
-        RTCDAY_DAY5: 5 = struct RTCDAY_DAY5(bool);
+        DAY5: 5 = struct DAY5(bool);
         /// Real Time Clock Day Bit: 6
-        RTCDAY_DAY6: 6 = struct RTCDAY_DAY6(bool);
+        DAY6: 6 = struct DAY6(bool);
     }
     /// Real Time Clock Month
-    rw RTCMON @ 0x15: u8 = 0_0 {
+    rw MON @ 0x15: u8 = 0_0 {
         /// Real Time Clock Month Bit: 0
         MONTH0: 0 = struct MONTH0(bool);
         /// Real Time Clock Month Bit: 1
@@ -372,183 +372,183 @@ utils::periph! {
         MONTH6: 6 = struct MONTH6(bool);
     }
     /// Real Time Clock Alarm Min
-    rw RTCAMIN @ 0x18: u8 = 0_0 {
+    rw AMIN @ 0x18: u8 = 0_0 {
         /// Real Time Clock Minutes Bit: 0
-        RTCAMIN_MINUTES0: 0 = struct RTCAMIN_MINUTES0(bool);
+        AMIN0: 0 = struct AMIN0(bool);
         /// Real Time Clock Minutes Bit: 1
-        RTCAMIN_MINUTES1: 1 = struct RTCAMIN_MINUTES1(bool);
+        AMIN1: 1 = struct AMIN1(bool);
         /// Real Time Clock Minutes Bit: 2
-        RTCAMIN_MINUTES2: 2 = struct RTCAMIN_MINUTES2(bool);
+        AMIN2: 2 = struct AMIN2(bool);
         /// Real Time Clock Minutes Bit: 3
-        RTCAMIN_MINUTES3: 3 = struct RTCAMIN_MINUTES3(bool);
+        AMIN3: 3 = struct AMIN3(bool);
         /// Real Time Clock Minutes Bit: 4
-        RTCAMIN_MINUTES4: 4 = struct RTCAMIN_MINUTES4(bool);
+        AMIN4: 4 = struct AMIN4(bool);
         /// Real Time Clock Minutes Bit: 5
-        RTCAMIN_MINUTES5: 5 = struct RTCAMIN_MINUTES5(bool);
+        AMIN5: 5 = struct AMIN5(bool);
         /// Real Time Clock Minutes Bit: 6
-        RTCAMIN_MINUTES6: 6 = struct RTCAMIN_MINUTES6(bool);
+        AMIN6: 6 = struct AMIN6(bool);
         /// Real Time Clock Alarm enable
-        RTCAMIN_RTCAE: 7 = struct RTCAMIN_RTCAE(bool);
+        AMIN_RTCAE: 7 = struct AMIN_RTCAE(bool);
     }
     /// Real Time Clock Alarm Hour
-    rw RTCAHOUR @ 0x19: u8 = 0_0 {
+    rw AHOUR @ 0x19: u8 = 0_0 {
         /// Real Time Clock Hour Bit: 0
-        RTCAHOUR_HOUR0: 0 = struct RTCAHOUR_HOUR0(bool);
+        AHOUR0: 0 = struct AHOUR0(bool);
         /// Real Time Clock Hour Bit: 1
-        RTCAHOUR_HOUR1: 1 = struct RTCAHOUR_HOUR1(bool);
+        AHOUR1: 1 = struct AHOUR1(bool);
         /// Real Time Clock Hour Bit: 2
-        RTCAHOUR_HOUR2: 2 = struct RTCAHOUR_HOUR2(bool);
+        AHOUR2: 2 = struct AHOUR2(bool);
         /// Real Time Clock Hour Bit: 3
-        RTCAHOUR_HOUR3: 3 = struct RTCAHOUR_HOUR3(bool);
+        AHOUR3: 3 = struct AHOUR3(bool);
         /// Real Time Clock Hour Bit: 4
-        RTCAHOUR_HOUR4: 4 = struct RTCAHOUR_HOUR4(bool);
+        AHOUR4: 4 = struct AHOUR4(bool);
         /// Real Time Clock Hour Bit: 5
-        RTCAHOUR_HOUR5: 5 = struct RTCAHOUR_HOUR5(bool);
+        AHOUR5: 5 = struct AHOUR5(bool);
         /// Real Time Clock Hour Bit: 6
-        RTCAHOUR_HOUR6: 6 = struct RTCAHOUR_HOUR6(bool);
+        AHOUR6: 6 = struct AHOUR6(bool);
         /// Real Time Clock Alarm enable
-        RTCAHOUR_RTCAE: 7 = struct RTCAHOUR_RTCAE(bool);
+        AHOUR_RTCAE: 7 = struct AHOUR_RTCAE(bool);
     }
     /// Real Time Clock Alarm Day of week
-    rw RTCADOW @ 0x1a: u8 = 0_0 {
+    rw ADOW @ 0x1a: u8 = 0_0 {
         /// Real Time Clock DOW Bit: 0
-        RTCADOW_DOW0: 0 = struct RTCADOW_DOW0(bool);
+        ADOW0: 0 = struct ADOW0(bool);
         /// Real Time Clock DOW Bit: 1
-        RTCADOW_DOW1: 1 = struct RTCADOW_DOW1(bool);
+        ADOW1: 1 = struct ADOW1(bool);
         /// Real Time Clock DOW Bit: 2
-        RTCADOW_DOW2: 2 = struct RTCADOW_DOW2(bool);
+        ADOW2: 2 = struct ADOW2(bool);
         /// Real Time Clock DOW Bit: 3
-        RTCADOW_DOW3: 3 = struct RTCADOW_DOW3(bool);
+        ADOW3: 3 = struct ADOW3(bool);
         /// Real Time Clock DOW Bit: 4
-        RTCADOW_DOW4: 4 = struct RTCADOW_DOW4(bool);
+        ADOW4: 4 = struct ADOW4(bool);
         /// Real Time Clock DOW Bit: 5
-        RTCADOW_DOW5: 5 = struct RTCADOW_DOW5(bool);
+        ADOW5: 5 = struct ADOW5(bool);
         /// Real Time Clock DOW Bit: 6
-        RTCADOW_DOW6: 6 = struct RTCADOW_DOW6(bool);
+        ADOW6: 6 = struct ADOW6(bool);
         /// Real Time Clock Alarm enable
-        RTCADOW_RTCAE: 7 = struct RTCADOW_RTCAE(bool);
+        ADOW_RTCAE: 7 = struct ADOW_RTCAE(bool);
     }
     /// Real Time Clock Alarm Day
-    rw RTCADAY @ 0x1b: u8 = 0_0 {
+    rw ADAY @ 0x1b: u8 = 0_0 {
         /// Real Time Clock Day Bit: 0
-        RTCADAY_DAY0: 0 = struct RTCADAY_DAY0(bool);
+        ADAY0: 0 = struct ADAY0(bool);
         /// Real Time Clock Day Bit: 1
-        RTCADAY_DAY1: 1 = struct RTCADAY_DAY1(bool);
+        ADAY1: 1 = struct ADAY1(bool);
         /// Real Time Clock Day Bit: 2
-        RTCADAY_DAY2: 2 = struct RTCADAY_DAY2(bool);
+        ADAY2: 2 = struct ADAY2(bool);
         /// Real Time Clock Day Bit: 3
-        RTCADAY_DAY3: 3 = struct RTCADAY_DAY3(bool);
+        ADAY3: 3 = struct ADAY3(bool);
         /// Real Time Clock Day Bit: 4
-        RTCADAY_DAY4: 4 = struct RTCADAY_DAY4(bool);
+        ADAY4: 4 = struct ADAY4(bool);
         /// Real Time Clock Day Bit: 5
-        RTCADAY_DAY5: 5 = struct RTCADAY_DAY5(bool);
+        ADAY5: 5 = struct ADAY5(bool);
         /// Real Time Clock Day Bit: 6
-        RTCADAY_DAY6: 6 = struct RTCADAY_DAY6(bool);
+        ADAY6: 6 = struct ADAY6(bool);
         /// Real Time Clock Alarm enable
-        RTCADAY_RTCAE: 7 = struct RTCADAY_RTCAE(bool);
+        ADAY_RTCAE: 7 = struct ADAY_RTCAE(bool);
     }
     /// Real-Time Clock Time Capture Control Register 0
-    rw RTCTCCTL0 @ 0x20: u8 = 0_0 {
+    rw TCCTL0 @ 0x20: u8 = 0_0 {
         /// RTC Enable for RTC Tamper Detection with Time Stamp
         TCEN: 0 = struct TCEN(bool);
         /// RTC Indication of power cycle on AUXVCC3
         AUX3RST: 1 = struct AUX3RST(bool);
     }
     /// Real-Time Clock Time Capture Control Register 1
-    rw RTCTCCTL1 @ 0x21: u8 = 0_0 {
+    rw TCCTL1 @ 0x21: u8 = 0_0 {
         /// RTC  Tamper Event Interrupt Flag
-        RTCCAPIFG: 0 = struct RTCCAPIFG(bool);
+        CAPIFG: 0 = struct CAPIFG(bool);
         /// RTC Tamper Event Interrupt Enable
-        RTCCAPIE: 1 = struct RTCCAPIE(bool);
+        CAPIE: 1 = struct CAPIE(bool);
     }
     /// Tamper Detect Pin 0 Control Register
-    rw RTCCAP0CTL @ 0x22: u8 = 0_0 {
+    rw CAP0CTL @ 0x22: u8 = 0_0 {
         /// RTC Tamper Event Flag
-        RTCCAP0CTL_CAPEV: 0 = struct RTCCAP0CTL_CAPEV(bool);
+        CAP0CAPEV: 0 = struct CAP0CAPEV(bool);
         /// RTC Event Edge Select
-        RTCCAP0CTL_CAPES: 2 = struct RTCCAP0CTL_CAPES(bool);
+        CAP0CAPES: 2 = struct CAP0CAPES(bool);
         /// RTC RTCCAPx pin pullup/pulldown resistor enable
-        RTCCAP0CTL_RTCREN: 3 = struct RTCCAP0CTL_RTCREN(bool);
+        CAP0RTCREN: 3 = struct CAP0RTCREN(bool);
         /// RTC RTCCAPx input
-        RTCCAP0CTL_RTCCAPIN: 4 = struct RTCCAP0CTL_RTCCAPIN(bool);
+        CAP0RTCCAPIN: 4 = struct CAP0RTCCAPIN(bool);
         /// RTC RTCCAPx Pin direction
-        RTCCAP0CTL_RTCCAPDIR: 5 = struct RTCCAP0CTL_RTCCAPDIR(bool);
+        CAP0RTCCAPDIR: 5 = struct CAP0RTCCAPDIR(bool);
         /// RTC RTCCAPx Output
-        RTCCAP0CTL_RTCCAPOUT: 6 = struct RTCCAP0CTL_RTCCAPOUT(bool);
+        CAP0RTCCAPOUT: 6 = struct CAP0RTCCAPOUT(bool);
     }
     /// Tamper Detect Pin 1 Control Register
-    rw RTCCAP1CTL @ 0x23: u8 = 0_0 {
+    rw CAP1CTL @ 0x23: u8 = 0_0 {
         /// RTC Tamper Event Flag
-        RTCCAP1CTL_CAPEV: 0 = struct RTCCAP1CTL_CAPEV(bool);
+        CAP1CAPEV: 0 = struct CAP1CAPEV(bool);
         /// RTC Event Edge Select
-        RTCCAP1CTL_CAPES: 2 = struct RTCCAP1CTL_CAPES(bool);
+        CAP1CAPES: 2 = struct CAP1CAPES(bool);
         /// RTC RTCCAPx pin pullup/pulldown resistor enable
-        RTCCAP1CTL_RTCREN: 3 = struct RTCCAP1CTL_RTCREN(bool);
+        CAP1RTCREN: 3 = struct CAP1RTCREN(bool);
         /// RTC RTCCAPx input
-        RTCCAP1CTL_RTCCAPIN: 4 = struct RTCCAP1CTL_RTCCAPIN(bool);
+        CAP1RTCCAPIN: 4 = struct CAP1RTCCAPIN(bool);
         /// RTC RTCCAPx Pin direction
-        RTCCAP1CTL_RTCCAPDIR: 5 = struct RTCCAP1CTL_RTCCAPDIR(bool);
+        CAP1RTCCAPDIR: 5 = struct CAP1RTCCAPDIR(bool);
         /// RTC RTCCAPx Output
-        RTCCAP1CTL_RTCCAPOUT: 6 = struct RTCCAP1CTL_RTCCAPOUT(bool);
+        CAP1RTCCAPOUT: 6 = struct CAP1RTCCAPOUT(bool);
     }
     /// Real-Time Clock Seconds Backup Register 0
-    rw RTCSECBAK0 @ 0x30: u8 = 0_0 {
+    rw SECBAK0 @ 0x30: u8 = 0_0 {
         /// Real-Time Clock Seconds Backup Register 0
-        RTCSECBAK0: 0..7 = struct RTCSECBAK0Field(u8);
+        SECBAK0: 0..7 = struct SECBAK0Field(u8);
     }
     /// Real-Time Clock Minutes Backup Register 0
-    rw RTCMINBAK0 @ 0x31: u8 = 0_0 {
+    rw MINBAK0 @ 0x31: u8 = 0_0 {
         /// Real-Time Clock Minutes Backup Register 0
-        RTCMINBAK0: 0..7 = struct RTCMINBAK0Field(u8);
+        MINBAK0: 0..7 = struct MINBAK0Field(u8);
     }
     /// Real-Time Clock Hours Backup Register 0
-    rw RTCHOURBAK0 @ 0x32: u8 = 0_0 {
+    rw HOURBAK0 @ 0x32: u8 = 0_0 {
         /// Real-Time Clock Hours Backup Register 0
-        RTCHOURBAK0: 0..7 = struct RTCHOURBAK0Field(u8);
+        HOURBAK0: 0..7 = struct HOURBAK0Field(u8);
     }
     /// Real-Time Clock Days Backup Register 0
-    rw RTCDAYBAK0 @ 0x33: u8 = 0_0 {
+    rw DAYBAK0 @ 0x33: u8 = 0_0 {
         /// Real-Time Clock Days Backup Register 0
-        RTCDAYBAK0: 0..7 = struct RTCDAYBAK0Field(u8);
+        DAYBAK0: 0..7 = struct DAYBAK0Field(u8);
     }
     /// Real-Time Clock Months Backup Register 0
-    rw RTCMONBAK0 @ 0x34: u8 = 0_0 {
+    rw MONBAK0 @ 0x34: u8 = 0_0 {
         /// Real-Time Clock Months Backup Register 0
-        RTCMONBAK0: 0..7 = struct RTCMONBAK0Field(u8);
+        MONBAK0: 0..7 = struct MONBAK0Field(u8);
     }
     /// Real-Time Clock year Backup Register 0
-    rw RTCYEARBAK0 @ 0x36: u8 = 0_0 {
+    rw YEARBAK0 @ 0x36: u8 = 0_0 {
         /// Real-Time Clock year Backup Register 0
-        RTCYEARBAK0: 0..7 = struct RTCYEARBAK0Field(u8);
+        YEARBAK0: 0..7 = struct YEARBAK0Field(u8);
     }
     /// Real-Time Clock Seconds Backup Register 1
-    rw RTCSECBAK1 @ 0x38: u8 = 0_0 {
+    rw SECBAK1 @ 0x38: u8 = 0_0 {
         /// Real-Time Clock Seconds Backup Register 1
-        RTCSECBAK1: 0..7 = struct RTCSECBAK1Field(u8);
+        SECBAK1: 0..7 = struct SECBAK1Field(u8);
     }
     /// Real-Time Clock Minutes Backup Register 1
-    rw RTCMINBAK1 @ 0x39: u8 = 0_0 {
+    rw MINBAK1 @ 0x39: u8 = 0_0 {
         /// Real-Time Clock Minutes Backup Register 1
-        RTCMINBAK1: 0..7 = struct RTCMINBAK1Field(u8);
+        MINBAK1: 0..7 = struct MINBAK1Field(u8);
     }
     /// Real-Time Clock Hours Backup Register 1
-    rw RTCHOURBAK1 @ 0x3a: u8 = 0_0 {
+    rw HOURBAK1 @ 0x3a: u8 = 0_0 {
         /// Real-Time Clock Hours Backup Register 1
-        RTCHOURBAK1: 0..7 = struct RTCHOURBAK1Field(u8);
+        HOURBAK1: 0..7 = struct HOURBAK1Field(u8);
     }
     /// Real-Time Clock Days Backup Register 1
-    rw RTCDAYBAK1 @ 0x3b: u8 = 0_0 {
+    rw DAYBAK1 @ 0x3b: u8 = 0_0 {
         /// Real-Time Clock Days Backup Register 1
-        RTCDAYBAK1: 0..7 = struct RTCDAYBAK1Field(u8);
+        DAYBAK1: 0..7 = struct DAYBAK1Field(u8);
     }
     /// Real-Time Clock Months Backup Register 1
-    rw RTCMONBAK1 @ 0x3c: u8 = 0_0 {
+    rw MONBAK1 @ 0x3c: u8 = 0_0 {
         /// Real-Time Clock Months Backup Register 1
-        RTCMONBAK1: 0..7 = struct RTCMONBAK1Field(u8);
+        MONBAK1: 0..7 = struct MONBAK1Field(u8);
     }
     /// Real-Time Clock Year Backup Register 1
-    rw RTCYEARBAK1 @ 0x3e: u8 = 0_0 {
+    rw YEARBAK1 @ 0x3e: u8 = 0_0 {
         /// Real-Time Clock Year Backup Register 1
-        RTCYEARBAK1: 0..7 = struct RTCYEARBAK1Field(u8);
+        YEARBAK1: 0..7 = struct YEARBAK1Field(u8);
     }
 }
