@@ -1,21 +1,21 @@
-//! Timer A3
+//! Timer A2
 
 utils::periph! {
-    /// Timer A3
-    TimerA3;
-    /// Timer A3 Interrupt Vector Word
-    rw TAIV @ 0x00: u16 = 0_0 {
-        /// Timer A3 Interrupt Vector Word
-        TAIV: 0..15 = struct TAIVField(u16);
+    /// Timer A2
+    TimerA2;
+    /// Timer A2 Interrupt Vector Word
+    rw IV @ 0x00: u16 = 0_0 {
+        /// Timer A2 Interrupt Vector Word
+        IV: 0..15 = struct IVField(u16);
     }
-    /// Timer A3 Control
-    rw TACTL @ 0x32: u16 = 0_0 {
+    /// Timer A2 Control
+    rw CTL @ 0x62: u16 = 0_0 {
         /// Timer A counter interrupt flag
-        TAIFG: 0 = struct TAIFG(bool);
+        IFG: 0 = struct IFG(bool);
         /// Timer A counter interrupt enable
-        TAIE: 1 = struct TAIE(bool);
+        IE: 1 = struct IE(bool);
         /// Timer A counter clear
-        TACLR: 2 = struct TACLR(bool);
+        CLR: 2 = struct CLR(bool);
         /// Timer A mode control 1
         MC: 4..5 = enum MC {
             /// Timer A mode control: 0 - Stop
@@ -39,31 +39,31 @@ utils::periph! {
             ID_3 = 0b11,
         }
         /// Timer A clock source select 1
-        TASSEL: 8..9 = enum TASSEL {
+        SSEL: 8..9 = enum SSEL {
             /// Timer A clock source select: 0 - TACLK
-            TASSEL_0 = 0b00,
+            SSEL_0 = 0b00,
             /// Timer A clock source select: 1 - ACLK
-            TASSEL_1 = 0b01,
+            SSEL_1 = 0b01,
             /// Timer A clock source select: 2 - SMCLK
-            TASSEL_2 = 0b10,
+            SSEL_2 = 0b10,
             /// Timer A clock source select: 3 - INCLK
-            TASSEL_3 = 0b11,
+            SSEL_3 = 0b11,
         }
     }
-    /// Timer A3 Capture/Compare Control 0
-    rw TACCTL0 @ 0x34: u16 = 0_0 {
+    /// Timer A2 Capture/Compare Control 0
+    rw CCTL0 @ 0x64: u16 = 0_0 {
         /// Capture/compare interrupt flag
-        TACCTL0_CCIFG: 0 = struct TACCTL0_CCIFG(bool);
+        C0CCIFG: 0 = struct C0CCIFG(bool);
         /// Capture/compare overflow flag
-        TACCTL0_COV: 1 = struct TACCTL0_COV(bool);
+        C0COV: 1 = struct C0COV(bool);
         /// PWM Output signal if output mode 0
-        TACCTL0_OUT: 2 = struct TACCTL0_OUT(bool);
+        C0OUT: 2 = struct C0OUT(bool);
         /// Capture input signal (read)
-        TACCTL0_CCI: 3 = struct TACCTL0_CCI(bool);
+        C0CCI: 3 = struct C0CCI(bool);
         /// Capture/compare interrupt enable
-        TACCTL0_CCIE: 4 = struct TACCTL0_CCIE(bool);
+        C0CCIE: 4 = struct C0CCIE(bool);
         /// Output mode 2
-        TACCTL0_OUTMOD: 5..7 = enum TACCTL0_OUTMOD {
+        C0OUTMOD: 5..7 = enum C0OUTMOD {
             /// PWM output mode: 0 - output only
             OUTMOD_0 = 0b000,
             /// PWM output mode: 1 - set
@@ -82,13 +82,13 @@ utils::periph! {
             OUTMOD_7 = 0b111,
         }
         /// Capture mode: 1 /Compare mode : 0
-        TACCTL0_CAP: 8 = struct TACCTL0_CAP(bool);
+        C0CAP: 8 = struct C0CAP(bool);
         /// Latched capture signal (read)
-        TACCTL0_SCCI: 10 = struct TACCTL0_SCCI(bool);
+        C0SCCI: 10 = struct C0SCCI(bool);
         /// Capture sychronize
-        TACCTL0_SCS: 11 = struct TACCTL0_SCS(bool);
+        C0SCS: 11 = struct C0SCS(bool);
         /// Capture input select 1
-        TACCTL0_CCIS: 12..13 = enum TACCTL0_CCIS {
+        C0CCIS: 12..13 = enum C0CCIS {
             /// Capture input select: 0 - CCIxA
             CCIS_0 = 0b00,
             /// Capture input select: 1 - CCIxB
@@ -99,7 +99,7 @@ utils::periph! {
             CCIS_3 = 0b11,
         }
         /// Capture mode 1
-        TACCTL0_CM: 14..15 = enum TACCTL0_CM {
+        C0CM: 14..15 = enum C0CM {
             /// Capture mode: 0 - disabled
             CM_0 = 0b00,
             /// Capture mode: 1 - pos. edge
@@ -110,20 +110,20 @@ utils::periph! {
             CM_3 = 0b11,
         }
     }
-    /// Timer A3 Capture/Compare Control 1
-    rw TACCTL1 @ 0x36: u16 = 0_0 {
+    /// Timer A2 Capture/Compare Control 1
+    rw CCTL1 @ 0x66: u16 = 0_0 {
         /// Capture/compare interrupt flag
-        TACCTL1_CCIFG: 0 = struct TACCTL1_CCIFG(bool);
+        C1CCIFG: 0 = struct C1CCIFG(bool);
         /// Capture/compare overflow flag
-        TACCTL1_COV: 1 = struct TACCTL1_COV(bool);
+        C1COV: 1 = struct C1COV(bool);
         /// PWM Output signal if output mode 0
-        TACCTL1_OUT: 2 = struct TACCTL1_OUT(bool);
+        C1OUT: 2 = struct C1OUT(bool);
         /// Capture input signal (read)
-        TACCTL1_CCI: 3 = struct TACCTL1_CCI(bool);
+        C1CCI: 3 = struct C1CCI(bool);
         /// Capture/compare interrupt enable
-        TACCTL1_CCIE: 4 = struct TACCTL1_CCIE(bool);
+        C1CCIE: 4 = struct C1CCIE(bool);
         /// Output mode 2
-        TACCTL1_OUTMOD: 5..7 = enum TACCTL1_OUTMOD {
+        C1OUTMOD: 5..7 = enum C1OUTMOD {
             /// PWM output mode: 0 - output only
             OUTMOD_0 = 0b000,
             /// PWM output mode: 1 - set
@@ -142,13 +142,13 @@ utils::periph! {
             OUTMOD_7 = 0b111,
         }
         /// Capture mode: 1 /Compare mode : 0
-        TACCTL1_CAP: 8 = struct TACCTL1_CAP(bool);
+        C1CAP: 8 = struct C1CAP(bool);
         /// Latched capture signal (read)
-        TACCTL1_SCCI: 10 = struct TACCTL1_SCCI(bool);
+        C1SCCI: 10 = struct C1SCCI(bool);
         /// Capture sychronize
-        TACCTL1_SCS: 11 = struct TACCTL1_SCS(bool);
+        C1SCS: 11 = struct C1SCS(bool);
         /// Capture input select 1
-        TACCTL1_CCIS: 12..13 = enum TACCTL1_CCIS {
+        C1CCIS: 12..13 = enum C1CCIS {
             /// Capture input select: 0 - CCIxA
             CCIS_0 = 0b00,
             /// Capture input select: 1 - CCIxB
@@ -159,7 +159,7 @@ utils::periph! {
             CCIS_3 = 0b11,
         }
         /// Capture mode 1
-        TACCTL1_CM: 14..15 = enum TACCTL1_CM {
+        C1CM: 14..15 = enum C1CM {
             /// Capture mode: 0 - disabled
             CM_0 = 0b00,
             /// Capture mode: 1 - pos. edge
@@ -170,84 +170,19 @@ utils::periph! {
             CM_3 = 0b11,
         }
     }
-    /// Timer A3 Capture/Compare Control 2
-    rw TACCTL2 @ 0x38: u16 = 0_0 {
-        /// Capture/compare interrupt flag
-        TACCTL2_CCIFG: 0 = struct TACCTL2_CCIFG(bool);
-        /// Capture/compare overflow flag
-        TACCTL2_COV: 1 = struct TACCTL2_COV(bool);
-        /// PWM Output signal if output mode 0
-        TACCTL2_OUT: 2 = struct TACCTL2_OUT(bool);
-        /// Capture input signal (read)
-        TACCTL2_CCI: 3 = struct TACCTL2_CCI(bool);
-        /// Capture/compare interrupt enable
-        TACCTL2_CCIE: 4 = struct TACCTL2_CCIE(bool);
-        /// Output mode 2
-        TACCTL2_OUTMOD: 5..7 = enum TACCTL2_OUTMOD {
-            /// PWM output mode: 0 - output only
-            OUTMOD_0 = 0b000,
-            /// PWM output mode: 1 - set
-            OUTMOD_1 = 0b001,
-            /// PWM output mode: 2 - PWM toggle/reset
-            OUTMOD_2 = 0b010,
-            /// PWM output mode: 3 - PWM set/reset
-            OUTMOD_3 = 0b011,
-            /// PWM output mode: 4 - toggle
-            OUTMOD_4 = 0b100,
-            /// PWM output mode: 5 - Reset
-            OUTMOD_5 = 0b101,
-            /// PWM output mode: 6 - PWM toggle/set
-            OUTMOD_6 = 0b110,
-            /// PWM output mode: 7 - PWM reset/set
-            OUTMOD_7 = 0b111,
-        }
-        /// Capture mode: 1 /Compare mode : 0
-        TACCTL2_CAP: 8 = struct TACCTL2_CAP(bool);
-        /// Latched capture signal (read)
-        TACCTL2_SCCI: 10 = struct TACCTL2_SCCI(bool);
-        /// Capture sychronize
-        TACCTL2_SCS: 11 = struct TACCTL2_SCS(bool);
-        /// Capture input select 1
-        TACCTL2_CCIS: 12..13 = enum TACCTL2_CCIS {
-            /// Capture input select: 0 - CCIxA
-            CCIS_0 = 0b00,
-            /// Capture input select: 1 - CCIxB
-            CCIS_1 = 0b01,
-            /// Capture input select: 2 - GND
-            CCIS_2 = 0b10,
-            /// Capture input select: 3 - Vcc
-            CCIS_3 = 0b11,
-        }
-        /// Capture mode 1
-        TACCTL2_CM: 14..15 = enum TACCTL2_CM {
-            /// Capture mode: 0 - disabled
-            CM_0 = 0b00,
-            /// Capture mode: 1 - pos. edge
-            CM_1 = 0b01,
-            /// Capture mode: 1 - neg. edge
-            CM_2 = 0b10,
-            /// Capture mode: 1 - both edges
-            CM_3 = 0b11,
-        }
+    /// Timer A2 Counter Register
+    rw R @ 0x72: u16 = 0_0 {
+        /// Timer A2 Counter Register
+        R: 0..15 = struct RField(u16);
     }
-    /// Timer A3 Counter Register
-    rw TAR @ 0x42: u16 = 0_0 {
-        /// Timer A3 Counter Register
-        TAR: 0..15 = struct TARField(u16);
+    /// Timer A2 Capture/Compare 0
+    rw CCR0 @ 0x74: u16 = 0_0 {
+        /// Timer A2 Capture/Compare 0
+        CCR0: 0..15 = struct CCR0Field(u16);
     }
-    /// Timer A3 Capture/Compare 0
-    rw TACCR0 @ 0x44: u16 = 0_0 {
-        /// Timer A3 Capture/Compare 0
-        TACCR0: 0..15 = struct TACCR0Field(u16);
-    }
-    /// Timer A3 Capture/Compare 1
-    rw TACCR1 @ 0x46: u16 = 0_0 {
-        /// Timer A3 Capture/Compare 1
-        TACCR1: 0..15 = struct TACCR1Field(u16);
-    }
-    /// Timer A3 Capture/Compare 2
-    rw TACCR2 @ 0x48: u16 = 0_0 {
-        /// Timer A3 Capture/Compare 2
-        TACCR2: 0..15 = struct TACCR2Field(u16);
+    /// Timer A2 Capture/Compare 1
+    rw CCR1 @ 0x76: u16 = 0_0 {
+        /// Timer A2 Capture/Compare 1
+        CCR1: 0..15 = struct CCR1Field(u16);
     }
 }
