@@ -4,13 +4,13 @@ utils::periph! {
     /// Timer D3
     TimerD3;
     /// Timer D3 Control 0
-    rw TDCTL0 @ 0x00: u16 = 0_0 {
+    rw CTL0 @ 0x00: u16 = 0_0 {
         /// Timer D3 interrupt flag
-        TDIFG: 0 = struct TDIFG(bool);
+        IFG: 0 = struct IFG(bool);
         /// Timer D3 interrupt enable
-        TDIE: 1 = struct TDIE(bool);
+        IE: 1 = struct IE(bool);
         /// Timer D3 counter clear
-        TDCLR: 2 = struct TDCLR(bool);
+        CLR: 2 = struct CLR(bool);
         /// Timer D3 mode control 1
         MC: 4..5 = enum MC {
             /// Timer A mode control: 0 - Stop
@@ -34,15 +34,15 @@ utils::periph! {
             ID_3 = 0b11,
         }
         /// Clock source 1
-        TDSSEL: 8..9 = enum TDSSEL {
+        SSEL: 8..9 = enum SSEL {
             /// Clock Source: TDCLK
-            TDSSEL_0 = 0b00,
+            SSEL_0 = 0b00,
             /// Clock Source: ACLK
-            TDSSEL_1 = 0b01,
+            SSEL_1 = 0b01,
             /// Clock Source: SMCLK
-            TDSSEL_2 = 0b10,
+            SSEL_2 = 0b10,
             /// Clock Source: INCLK
-            TDSSEL_3 = 0b11,
+            SSEL_3 = 0b11,
         }
         /// Counter lenght 1
         CNTL: 11..12 = enum CNTL {
@@ -56,27 +56,27 @@ utils::periph! {
             CNTL_3 = 0b11,
         }
         /// Timer D3 Compare latch load group 1
-        TDCLGRP: 13..14 = enum TDCLGRP {
+        CLGRP: 13..14 = enum CLGRP {
             /// Timer D3 Group: 0 - individually
-            TDCLGRP_0 = 0b00,
+            CLGRP_0 = 0b00,
             /// Timer D3 Group: 1 - 3 groups (1-2
-            TDCLGRP_1 = 0b01,
+            CLGRP_1 = 0b01,
             /// Timer D3 Group: 2 - 2 groups (1-3
-            TDCLGRP_2 = 0b10,
+            CLGRP_2 = 0b10,
             /// Timer D3 Group: 3 - 1 group (all)
-            TDCLGRP_3 = 0b11,
+            CLGRP_3 = 0b11,
         }
     }
     /// Timer D3 Control 1
-    rw TDCTL1 @ 0x02: u16 = 0_0 {
+    rw CTL1 @ 0x02: u16 = 0_0 {
         /// Timer D3 Clocking Mode Bit: 0
-        TDCLKM: 0..1 = enum TDCLKM {
+        CLKM: 0..1 = enum CLKM {
             /// Timer D3 Clocking Mode: External
-            TDCLKM_0 = 0b00,
+            CLKM_0 = 0b00,
             /// Timer D3 Clocking Mode: High-Res. local clock
-            TDCLKM_1 = 0b01,
+            CLKM_1 = 0b01,
             /// Timer D3 Clocking Mode: Aux Clock
-            TDCLKM_2 = 0b10,
+            CLKM_2 = 0b10,
         }
         /// Timer D3 TDCCR Combination in TD2
         TD2CMB: 4 = struct TD2CMB(bool);
@@ -85,61 +85,61 @@ utils::periph! {
         /// Timer D3 TDCCR Combination in TD6
         TD6CMB: 6 = struct TD6CMB(bool);
         /// Timer D3 Input divider expansion Bit: 0
-        TDIDEX: 8..10 = enum TDIDEX {
+        IDEX: 8..10 = enum IDEX {
             /// Timer D3 Input divider expansion : /1
-            TDIDEX_0 = 0b000,
+            IDEX_0 = 0b000,
             /// Timer D3 Input divider expansion : /2
-            TDIDEX_1 = 0b001,
+            IDEX_1 = 0b001,
             /// Timer D3 Input divider expansion : /3
-            TDIDEX_2 = 0b010,
+            IDEX_2 = 0b010,
             /// Timer D3 Input divider expansion : /4
-            TDIDEX_3 = 0b011,
+            IDEX_3 = 0b011,
             /// Timer D3 Input divider expansion : /5
-            TDIDEX_4 = 0b100,
+            IDEX_4 = 0b100,
             /// Timer D3 Input divider expansion : /6
-            TDIDEX_5 = 0b101,
+            IDEX_5 = 0b101,
             /// Timer D3 Input divider expansion : /7
-            TDIDEX_6 = 0b110,
+            IDEX_6 = 0b110,
             /// Timer D3 Input divider expansion : /8
-            TDIDEX_7 = 0b111,
+            IDEX_7 = 0b111,
         }
     }
     /// Timer D3 Control 2
-    rw TDCTL2 @ 0x04: u16 = 0_0 {
+    rw CTL2 @ 0x04: u16 = 0_0 {
         /// Timer D3 Capture Mode of Channel 0
-        TDCAPM0: 0 = struct TDCAPM0(bool);
+        CAPM0: 0 = struct CAPM0(bool);
         /// Timer D3 Capture Mode of Channel 1
-        TDCAPM1: 1 = struct TDCAPM1(bool);
+        CAPM1: 1 = struct CAPM1(bool);
         /// Timer D3 Capture Mode of Channel 2
-        TDCAPM2: 2 = struct TDCAPM2(bool);
+        CAPM2: 2 = struct CAPM2(bool);
         /// Timer D3 Capture Mode of Channel 3
-        TDCAPM3: 3 = struct TDCAPM3(bool);
+        CAPM3: 3 = struct CAPM3(bool);
         /// Timer D3 Capture Mode of Channel 4
-        TDCAPM4: 4 = struct TDCAPM4(bool);
+        CAPM4: 4 = struct CAPM4(bool);
         /// Timer D3 Capture Mode of Channel 5
-        TDCAPM5: 5 = struct TDCAPM5(bool);
+        CAPM5: 5 = struct CAPM5(bool);
         /// Timer D3 Capture Mode of Channel 6
-        TDCAPM6: 6 = struct TDCAPM6(bool);
+        CAPM6: 6 = struct CAPM6(bool);
     }
     /// Timer D3 Counter
-    rw TDR @ 0x06: u16 = 0_0 {
+    rw R @ 0x06: u16 = 0_0 {
         /// Timer D3 Counter
-        TDR: 0..15 = struct TDRField(u16);
+        R: 0..15 = struct RField(u16);
     }
     /// Timer D3 Capture/Compare Control 0
-    rw TDCCTL0 @ 0x08: u16 = 0_0 {
+    rw CCTL0 @ 0x08: u16 = 0_0 {
         /// Capture/compare interrupt flag
-        TDCCTL0_CCIFG: 0 = struct TDCCTL0_CCIFG(bool);
+        CCIFG0: 0 = struct CCIFG0(bool);
         /// Capture/compare overflow flag
-        TDCCTL0_COV: 1 = struct TDCCTL0_COV(bool);
+        COV0: 1 = struct COV0(bool);
         /// PWM Output signal if output mode 0
-        TDCCTL0_OUT: 2 = struct TDCCTL0_OUT(bool);
+        OUT0: 2 = struct OUT0(bool);
         /// Capture input signal (read)
-        TDCCTL0_CCI: 3 = struct TDCCTL0_CCI(bool);
+        CCI0: 3 = struct CCI0(bool);
         /// Capture/compare interrupt enable
-        TDCCTL0_CCIE: 4 = struct TDCCTL0_CCIE(bool);
+        CCIE0: 4 = struct CCIE0(bool);
         /// Output mode 2
-        TDCCTL0_OUTMOD: 5..7 = enum TDCCTL0_OUTMOD {
+        OUTMOD0: 5..7 = enum OUTMOD0 {
             /// PWM output mode: 0 - output only
             OUTMOD_0 = 0b000,
             /// PWM output mode: 1 - set
@@ -158,9 +158,9 @@ utils::periph! {
             OUTMOD_7 = 0b111,
         }
         /// Capture mode: 1 /Compare mode : 0
-        TDCCTL0_CAP: 8 = struct TDCCTL0_CAP(bool);
+        CAP0: 8 = struct CAP0(bool);
         /// Compare latch load source 1
-        TDCCTL0_CLLD: 9..10 = enum TDCCTL0_CLLD {
+        CLLD0: 9..10 = enum CLLD0 {
             /// Compare latch load sourec : 0 - immediate
             CLLD_0 = 0b00,
             /// Compare latch load sourec : 1 - TDR counts to 0
@@ -171,9 +171,9 @@ utils::periph! {
             CLLD_3 = 0b11,
         }
         /// Capture sychronize
-        TDCCTL0_SCS: 11 = struct TDCCTL0_SCS(bool);
+        SCS0: 11 = struct SCS0(bool);
         /// Capture input select 1
-        TDCCTL0_CCIS: 12..13 = enum TDCCTL0_CCIS {
+        CCIS0: 12..13 = enum CCIS0 {
             /// Capture input select: 0 - CCIxA
             CCIS_0 = 0b00,
             /// Capture input select: 1 - CCIxB
@@ -184,7 +184,7 @@ utils::periph! {
             CCIS_3 = 0b11,
         }
         /// Capture mode 1
-        TDCCTL0_CM: 14..15 = enum TDCCTL0_CM {
+        CM0: 14..15 = enum CM0 {
             /// Capture mode: 0 - disabled
             CM_0 = 0b00,
             /// Capture mode: 1 - pos. edge
@@ -196,29 +196,29 @@ utils::periph! {
         }
     }
     /// Timer D3 Capture/Compare 0
-    rw TDCCR0 @ 0x0a: u16 = 0_0 {
+    rw CCR0 @ 0x0a: u16 = 0_0 {
         /// Timer D3 Capture/Compare 0
-        TDCCR0: 0..15 = struct TDCCR0Field(u16);
+        CCR0: 0..15 = struct CCR0Field(u16);
     }
     /// Timer D3 Capture/Compare Latch 0
-    rw TDCL0 @ 0x0c: u16 = 0_0 {
+    rw CL0 @ 0x0c: u16 = 0_0 {
         /// Timer D3 Capture/Compare Latch 0
-        TDCL0: 0..15 = struct TDCL0Field(u16);
+        CL0: 0..15 = struct CL0Field(u16);
     }
     /// Timer D3 Capture/Compare Control 1
-    rw TDCCTL1 @ 0x0e: u16 = 0_0 {
+    rw CCTL1 @ 0x0e: u16 = 0_0 {
         /// Capture/compare interrupt flag
-        TDCCTL1_CCIFG: 0 = struct TDCCTL1_CCIFG(bool);
+        CCIFG1: 0 = struct CCIFG1(bool);
         /// Capture/compare overflow flag
-        TDCCTL1_COV: 1 = struct TDCCTL1_COV(bool);
+        COV1: 1 = struct COV1(bool);
         /// PWM Output signal if output mode 0
-        TDCCTL1_OUT: 2 = struct TDCCTL1_OUT(bool);
+        OUT1: 2 = struct OUT1(bool);
         /// Capture input signal (read)
-        TDCCTL1_CCI: 3 = struct TDCCTL1_CCI(bool);
+        CCI1: 3 = struct CCI1(bool);
         /// Capture/compare interrupt enable
-        TDCCTL1_CCIE: 4 = struct TDCCTL1_CCIE(bool);
+        CCIE1: 4 = struct CCIE1(bool);
         /// Output mode 2
-        TDCCTL1_OUTMOD: 5..7 = enum TDCCTL1_OUTMOD {
+        OUTMOD1: 5..7 = enum OUTMOD1 {
             /// PWM output mode: 0 - output only
             OUTMOD_0 = 0b000,
             /// PWM output mode: 1 - set
@@ -237,9 +237,9 @@ utils::periph! {
             OUTMOD_7 = 0b111,
         }
         /// Capture mode: 1 /Compare mode : 0
-        TDCCTL1_CAP: 8 = struct TDCCTL1_CAP(bool);
+        CAP1: 8 = struct CAP1(bool);
         /// Compare latch load source 1
-        TDCCTL1_CLLD: 9..10 = enum TDCCTL1_CLLD {
+        CLLD1: 9..10 = enum CLLD1 {
             /// Compare latch load sourec : 0 - immediate
             CLLD_0 = 0b00,
             /// Compare latch load sourec : 1 - TDR counts to 0
@@ -250,9 +250,9 @@ utils::periph! {
             CLLD_3 = 0b11,
         }
         /// Capture sychronize
-        TDCCTL1_SCS: 11 = struct TDCCTL1_SCS(bool);
+        SCS1: 11 = struct SCS1(bool);
         /// Capture input select 1
-        TDCCTL1_CCIS: 12..13 = enum TDCCTL1_CCIS {
+        CCIS1: 12..13 = enum CCIS1 {
             /// Capture input select: 0 - CCIxA
             CCIS_0 = 0b00,
             /// Capture input select: 1 - CCIxB
@@ -263,7 +263,7 @@ utils::periph! {
             CCIS_3 = 0b11,
         }
         /// Capture mode 1
-        TDCCTL1_CM: 14..15 = enum TDCCTL1_CM {
+        CM1: 14..15 = enum CM1 {
             /// Capture mode: 0 - disabled
             CM_0 = 0b00,
             /// Capture mode: 1 - pos. edge
@@ -275,29 +275,29 @@ utils::periph! {
         }
     }
     /// Timer D3 Capture/Compare 1
-    rw TDCCR1 @ 0x10: u16 = 0_0 {
+    rw CCR1 @ 0x10: u16 = 0_0 {
         /// Timer D3 Capture/Compare 1
-        TDCCR1: 0..15 = struct TDCCR1Field(u16);
+        CCR1: 0..15 = struct CCR1Field(u16);
     }
     /// Timer D3 Capture/Compare Latch 1
-    rw TDCL1 @ 0x12: u16 = 0_0 {
+    rw CL1 @ 0x12: u16 = 0_0 {
         /// Timer D3 Capture/Compare Latch 1
-        TDCL1: 0..15 = struct TDCL1Field(u16);
+        CL1: 0..15 = struct CL1Field(u16);
     }
     /// Timer D3 Capture/Compare Control 2
-    rw TDCCTL2 @ 0x14: u16 = 0_0 {
+    rw CCTL2 @ 0x14: u16 = 0_0 {
         /// Capture/compare interrupt flag
-        TDCCTL2_CCIFG: 0 = struct TDCCTL2_CCIFG(bool);
+        CCIFG2: 0 = struct CCIFG2(bool);
         /// Capture/compare overflow flag
-        TDCCTL2_COV: 1 = struct TDCCTL2_COV(bool);
+        COV2: 1 = struct COV2(bool);
         /// PWM Output signal if output mode 0
-        TDCCTL2_OUT: 2 = struct TDCCTL2_OUT(bool);
+        OUT2: 2 = struct OUT2(bool);
         /// Capture input signal (read)
-        TDCCTL2_CCI: 3 = struct TDCCTL2_CCI(bool);
+        CCI2: 3 = struct CCI2(bool);
         /// Capture/compare interrupt enable
-        TDCCTL2_CCIE: 4 = struct TDCCTL2_CCIE(bool);
+        CCIE2: 4 = struct CCIE2(bool);
         /// Output mode 2
-        TDCCTL2_OUTMOD: 5..7 = enum TDCCTL2_OUTMOD {
+        OUTMOD2: 5..7 = enum OUTMOD2 {
             /// PWM output mode: 0 - output only
             OUTMOD_0 = 0b000,
             /// PWM output mode: 1 - set
@@ -316,9 +316,9 @@ utils::periph! {
             OUTMOD_7 = 0b111,
         }
         /// Capture mode: 1 /Compare mode : 0
-        TDCCTL2_CAP: 8 = struct TDCCTL2_CAP(bool);
+        CAP2: 8 = struct CAP2(bool);
         /// Compare latch load source 1
-        TDCCTL2_CLLD: 9..10 = enum TDCCTL2_CLLD {
+        CLLD2: 9..10 = enum CLLD2 {
             /// Compare latch load sourec : 0 - immediate
             CLLD_0 = 0b00,
             /// Compare latch load sourec : 1 - TDR counts to 0
@@ -329,9 +329,9 @@ utils::periph! {
             CLLD_3 = 0b11,
         }
         /// Capture sychronize
-        TDCCTL2_SCS: 11 = struct TDCCTL2_SCS(bool);
+        SCS2: 11 = struct SCS2(bool);
         /// Capture input select 1
-        TDCCTL2_CCIS: 12..13 = enum TDCCTL2_CCIS {
+        CCIS2: 12..13 = enum CCIS2 {
             /// Capture input select: 0 - CCIxA
             CCIS_0 = 0b00,
             /// Capture input select: 1 - CCIxB
@@ -342,7 +342,7 @@ utils::periph! {
             CCIS_3 = 0b11,
         }
         /// Capture mode 1
-        TDCCTL2_CM: 14..15 = enum TDCCTL2_CM {
+        CM2: 14..15 = enum CM2 {
             /// Capture mode: 0 - disabled
             CM_0 = 0b00,
             /// Capture mode: 1 - pos. edge
@@ -354,101 +354,101 @@ utils::periph! {
         }
     }
     /// Timer D3 Capture/Compare 2
-    rw TDCCR2 @ 0x16: u16 = 0_0 {
+    rw CCR2 @ 0x16: u16 = 0_0 {
         /// Timer D3 Capture/Compare 2
-        TDCCR2: 0..15 = struct TDCCR2Field(u16);
+        CCR2: 0..15 = struct CCR2Field(u16);
     }
     /// Timer D3 Capture/Compare Latch 2
-    rw TDCL2 @ 0x18: u16 = 0_0 {
+    rw CL2 @ 0x18: u16 = 0_0 {
         /// Timer D3 Capture/Compare Latch 2
-        TDCL2: 0..15 = struct TDCL2Field(u16);
+        CL2: 0..15 = struct CL2Field(u16);
     }
     /// Timer D3 High-resolution Control Register 0
-    rw TDHCTL0 @ 0x38: u16 = 0_0 {
+    rw HCTL0 @ 0x38: u16 = 0_0 {
         /// Timer D3 High-Resolution Enable
-        TDHEN: 0 = struct TDHEN(bool);
+        HEN: 0 = struct HEN(bool);
         /// Timer D3 High-Resolution Regulated Mode
-        TDHREGEN: 1 = struct TDHREGEN(bool);
+        HREGEN: 1 = struct HREGEN(bool);
         /// Timer D3 High-Resolution clock error accum. enable
-        TDHEAEN: 2 = struct TDHEAEN(bool);
+        HEAEN: 2 = struct HEAEN(bool);
         /// Timer D3 High-Resolution Generator forced on
-        TDHRON: 3 = struct TDHRON(bool);
+        HRON: 3 = struct HRON(bool);
         /// Timer D3 High-Resoltuion Clock Mult. Bit: 0
-        TDHM: 4..5 = enum TDHM {
+        HM: 4..5 = enum HM {
             /// Timer D3 High-Resoltuion Clock Mult.: 8x TimerD clock
-            TDHM_0 = 0b00,
+            HM_0 = 0b00,
             /// Timer D3 High-Resoltuion Clock Mult.: 16x TimerD clock
-            TDHM_1 = 0b01,
+            HM_1 = 0b01,
         }
         /// Timer D3 High-Resolution clock divider Bit: 0
-        TDHD: 6..7 = enum TDHD {
+        HD: 6..7 = enum HD {
             /// Timer D3 High-Resolution clock divider: /1
-            TDHD_0 = 0b00,
+            HD_0 = 0b00,
             /// Timer D3 High-Resolution clock divider: /2
-            TDHD_1 = 0b01,
+            HD_1 = 0b01,
             /// Timer D3 High-Resolution clock divider: /4
-            TDHD_2 = 0b10,
+            HD_2 = 0b10,
             /// Timer D3 High-Resolution clock divider: /8
-            TDHD_3 = 0b11,
+            HD_3 = 0b11,
         }
         /// Timer0_D7 High-resolution generator fast wakeup enable
-        TDHFW: 8 = struct TDHFW(bool);
+        HFW: 8 = struct HFW(bool);
     }
     /// Timer D3 High-resolution Control Register 1
-    rw TDHCTL1 @ 0x3a: u16 = 0_0 {
+    rw HCTL1 @ 0x3a: u16 = 0_0 {
         /// Timer D3 High-Resolution Clock Trim Bit: 0
-        TDHCLKTRIM0: 1 = struct TDHCLKTRIM0(bool);
+        HCLKTRIM0: 1 = struct HCLKTRIM0(bool);
         /// Timer D3 High-Resolution Clock Trim Bit: 1
-        TDHCLKTRIM1: 2 = struct TDHCLKTRIM1(bool);
+        HCLKTRIM1: 2 = struct HCLKTRIM1(bool);
         /// Timer D3 High-Resolution Clock Trim Bit: 2
-        TDHCLKTRIM2: 3 = struct TDHCLKTRIM2(bool);
+        HCLKTRIM2: 3 = struct HCLKTRIM2(bool);
         /// Timer D3 High-Resolution Clock Trim Bit: 3
-        TDHCLKTRIM3: 4 = struct TDHCLKTRIM3(bool);
+        HCLKTRIM3: 4 = struct HCLKTRIM3(bool);
         /// Timer D3 High-Resolution Clock Trim Bit: 4
-        TDHCLKTRIM4: 5 = struct TDHCLKTRIM4(bool);
+        HCLKTRIM4: 5 = struct HCLKTRIM4(bool);
         /// Timer D3 High-Resolution Clock Trim Bit: 5
-        TDHCLKTRIM5: 6 = struct TDHCLKTRIM5(bool);
+        HCLKTRIM5: 6 = struct HCLKTRIM5(bool);
         /// Timer D3 High-Resolution Clock Trim Bit: 6
-        TDHCLKTRIM6: 7 = struct TDHCLKTRIM6(bool);
+        HCLKTRIM6: 7 = struct HCLKTRIM6(bool);
         /// Timer D3 High-Resolution Clock Sub-Range Bit: 0
-        TDHCLKSR0: 8 = struct TDHCLKSR0(bool);
+        HCLKSR0: 8 = struct HCLKSR0(bool);
         /// Timer D3 High-Resolution Clock Sub-Range Bit: 1
-        TDHCLKSR1: 9 = struct TDHCLKSR1(bool);
+        HCLKSR1: 9 = struct HCLKSR1(bool);
         /// Timer D3 High-Resolution Clock Sub-Range Bit: 2
-        TDHCLKSR2: 10 = struct TDHCLKSR2(bool);
+        HCLKSR2: 10 = struct HCLKSR2(bool);
         /// Timer D3 High-Resolution Clock Sub-Range Bit: 3
-        TDHCLKSR3: 11 = struct TDHCLKSR3(bool);
+        HCLKSR3: 11 = struct HCLKSR3(bool);
         /// Timer D3 High-Resolution Clock Sub-Range Bit: 4
-        TDHCLKSR4: 12 = struct TDHCLKSR4(bool);
+        HCLKSR4: 12 = struct HCLKSR4(bool);
         /// Timer D3 High-Resolution Clock Range Bit: 0
-        TDHCLKR0: 13 = struct TDHCLKR0(bool);
+        HCLKR0: 13 = struct HCLKR0(bool);
         /// Timer D3 High-Resolution Clock Range Bit: 1
-        TDHCLKR1: 14 = struct TDHCLKR1(bool);
+        HCLKR1: 14 = struct HCLKR1(bool);
         /// Timer D3 High-Resolution Coarse Clock Range
-        TDHCLKCR: 15 = struct TDHCLKCR(bool);
+        HCLKCR: 15 = struct HCLKCR(bool);
     }
     /// Timer D3 High-resolution Interrupt Register
-    rw TDHINT @ 0x3c: u16 = 0_0 {
+    rw HINT @ 0x3c: u16 = 0_0 {
         /// Timer D3 High-Res. fail low Interrupt Flag
-        TDHFLIFG: 0 = struct TDHFLIFG(bool);
+        HFLIFG: 0 = struct HFLIFG(bool);
         /// Timer D3 High-Res. fail high Interrupt Flag
-        TDHFHIFG: 1 = struct TDHFHIFG(bool);
+        HFHIFG: 1 = struct HFHIFG(bool);
         /// Timer D3 High-Res. frequency lock Interrupt Flag
-        TDHLKIFG: 2 = struct TDHLKIFG(bool);
+        HLKIFG: 2 = struct HLKIFG(bool);
         /// Timer D3 High-Res. frequency unlock Interrupt Flag
-        TDHUNLKIFG: 3 = struct TDHUNLKIFG(bool);
+        HUNLKIFG: 3 = struct HUNLKIFG(bool);
         /// Timer D3 High-Res. fail low Interrupt Enable
-        TDHFLIE: 8 = struct TDHFLIE(bool);
+        HFLIE: 8 = struct HFLIE(bool);
         /// Timer D3 High-Res. fail high Interrupt Enable
-        TDHFHIE: 9 = struct TDHFHIE(bool);
+        HFHIE: 9 = struct HFHIE(bool);
         /// Timer D3 High-Res. frequency lock Interrupt Enable
-        TDHLKIE: 10 = struct TDHLKIE(bool);
+        HLKIE: 10 = struct HLKIE(bool);
         /// Timer D3 High-Res. frequency unlock Interrupt Enable
-        TDHUNLKIE: 11 = struct TDHUNLKIE(bool);
+        HUNLKIE: 11 = struct HUNLKIE(bool);
     }
     /// Timer D3 Interrupt Vector Word
-    rw TDIV @ 0x3e: u16 = 0_0 {
+    rw IV @ 0x3e: u16 = 0_0 {
         /// Timer D3 Interrupt Vector Word
-        TDIV: 0..15 = struct TDIVField(u16);
+        IV: 0..15 = struct IVField(u16);
     }
 }
